'==========================================================================
'               DYNAMIC WOOD BURNING ANALYSIS PROGRAM
'==========================================================================
'          SCANADA CONSULTANTS LIMITED
'          DEVELOPED BY  M.C. SWINTON     1985, 1986, 1987
'                        M.D. MONETTE     1985
'                        R.P. SINHA       1986, 1987
'                        C.J. McLARNON    1987
'                        A.J. PAREKH      1989
'                      J.R.Y. LEMOINE     1989
'==========================================================================
'      MODEL TO SIMULATE WOOD BURNING
'      DEVELOPED BY SCANADA CONSULTANTS LIMITED
'      FOR CANADA MORTGAGE AND HOUSING CORPORATION
'==========================================================================
'
DECLARE SUB Element.prop ()
DECLARE SUB PLOTW ()
DECLARE SUB LineSummary (flag%)
DECLARE SUB friction.factors ()
DECLARE SUB screen.setup ()
DECLARE SUB Ini.Character ()
DECLARE SUB Print.constants ()
DECLARE SUB Network.points ()
DECLARE SUB IniTempProfile ()
DECLARE SUB IniConditions ()
DECLARE SUB Light.Wood ()
DECLARE SUB Light.Analysis ()
DECLARE SUB mass.flow ()
DECLARE SUB pressure.par ()
DECLARE SUB print1 ()
DECLARE SUB print2 ()
DECLARE SUB burn.rate ()
DECLARE SUB energy.balance ()
DECLARE SUB print.network ()
DECLARE SUB summary.print ()
DECLARE SUB print.all ()
DECLARE SUB flue.heattransfer ()
DECLARE SUB temp.update ()
DECLARE SUB film.coeff ()
DECLARE SUB display1.screen ()
DECLARE SUB display2.screen ()
DECLARE SUB screen.graphics ()
DECLARE SUB values.pr2 ()
DECLARE SUB check.display ()
DECLARE SUB qoutrad1 ()
DECLARE SUB room.surface ()
'==========================================================================
' $INCLUDE: 'WOODCOM5.BAS'
' $INCLUDE: 'WOODSMDC.BAS'
' $INCLUDE: 'WOODSIMC.BAS'
  DATA  0,1.,0,3.2,0.5,0,0,0,0,0,4.0,0,0,0,3.0,0,0,2.5,0
   ON ERROR GOTO 29000
   CPWENV(1) = .7: CPWENV(2) = -.5: CPWENV(3) = -.7: CPWENV(4) = -.3: CPWENV(5) = 0!
   FOR I% = 2 TO 5: ARD(I%) = AR(I%): NEXT
   INDCOMB% = 1
    MASTER% = 1234
    setup% = 0
    OPEN OU$ FOR OUTPUT AS #2: OPEN PW$ FOR OUTPUT AS #4
    PRINT #2, CHR$(15)
    WIDTH #2, 255: CLS
    IF PRFLAG2% = 5678 THEN CALL LineSummary(0): IF FL1% = 0 THEN CALL screen.setup: GOTO 3000 ELSE GOTO 3000
    PRFLAG2% = 0
    '
    CLS : PRINT : PRINT " EXECUTION OF THE WOOD BURNING SIMULATOR  PROGRAM"
              PRINT " ------------------------------------------------"
    T = TIMER: WHILE TIMER < T + 1: WEND
    MFIPOT = 0!
    K1 = .1' K1=(NELBOWS%*.9)+1.4
    UI = 5 * 1.8: UF = 5 * 1.8
    MU = .0000184
    CPAIR = 1035
    GC = 9.8
    PIE = 3.141593
    TA = 273.15
    GF = 0
    XD = 0
    RISET = ABS(CHBOT - HT(5))
    ELAENV = 1.157 * ((353.6 / (T1 + TA)) ^ .5) * C * ((10) ^ (N - .5))
    KEINT = (NELINT * 1) + 2.69 + 1
    ELAINT = ARINT * 1.64 / SQR(KEINT)
    VCL = ((LNPP * ELAENV) + (VCLINT * ELAINT)) / (ELAENV + ELAINT)
    ELAENV = ELAENV + ELAINT
    CC = ELAENV / ((10 ^ (N - .5)) * 1.157 * (353.6 / (T1 + TA)) ^ .5)
    HT(8) = VCL: HT(9) = VCL
     PRINT #2, "MODEL OF THE TRANSIENT PERFORMANCE OF A WOODBURNING DEVICE AND A CHIMNEY IN NON-DESIGN FLOW CONDITIONS"
    PRINT #2, "=================================================================================="
    PRINT #2, : PRINT #2, "PROGRAM DEVELOPED BY: SCANADA CONSULTANTS LIMITED"
    PRINT #2, "                 FOR:CANADA MORTGAGE AND HOUSING CORPORATION"
    PRINT #2, "                 DATE:1984,1986,1989 "
    PRINT #2, "=================================================================================="
    PRINT #2, : PRINT #2,
     REM
     REM
      REM====================================================================
      REM
      REM    SUBROUTINE GUIDE:
      REM       friction.factors -FRICTION FACTORS AND ELA's OF THE SYSTEM
      REM  IniTempProfile     4500-INITIAL TEMPERATURE PROFILES FOR FLUE AND GAS FLOW NETWORK
      REM  mass.flow     5000-MASS FLOW SUBROUTINE
      REM  Pressure.par     6000-CALCULATION OF PRESSURE PARAMETERS
      REM  Element.prop     8000-SPECIFICATION OF ELEMENTAL PROPERTIES OF THE FLUE & FIREBOX
      REM  flue.heattransfer     9000-FLUE TRANSIENT HEAT TRANSFER ROUTINE
      REM       10500-MATH MODULE
      REM  Light.Analysis     11000-PARAMETER ANALYSIS AT LIGHTING OF FIRE
      REM  temp.update     12020-TEMPERATURE UPDATE ROUTINE
      REM  film.coeff     12500-FLUE FILM HT. TRANSFER COEFFICIENT AND FRICTION FACTORS
      REM  Print2     13000-OUTPUT ROUTINE TO PRINT TEMPERATURES OF FLUE ELEMENTS
      REM  print.network     14000-FLOW NETWORK PAPRMETER ROUTINE
      REM  Print.constants     15000-PHYSICAL CHARACTERISITCS OF THE SYSTEM
      REM  Network.points 16000-GUIDE TO IDENTIFY NETWORK POINTS
     REM   summary.print     17000-SUMMARY TABLE OUTPUT
     REM        18000-LINE SUMMARY OUTPUT FOR EACH CALCULATION INTERVAL
     REM  LineSummary       18500-HEADINGS FOR LINE SUMMARY
     REM        19750-FLUE TEMPERATURE PROFILE OUTPUT
      REM  PLOTW     20000-ON-LINE GRAPHICS ROUTINE
     REM  Ini.Character      25000-INITIALIZE THE WOOD BURNING ROUTINE
     REM  burn.rate      27000-DYNAMIC THERMAL MODEL OF WOOD BURNING
      REM====================================================================
      REM
      REM====================================================================
      REM
      REM  : BOUNDARY CONDITIONS AND INITIAL CONDITIONS TO START THE ITERATIONS
      REM
      REM====================================================================
      REM
      REM :-------------BOUNDARY CONDITIONS-----------------
      REM
     IF THETAW = 0 THEN PVC = 1: GOTO 1590
     IF THETAW < 0 THEN SN = -1 ELSE SN = 1
     PVC = SN * (PTC - PHC * (COS(THETAW * PIE / 180!) ^ 2)) / (SIN(THETAW * PIE / 180!) ^ 2)
1590 VH = VWINDT * COS(THETAW * PIE / 180!)
     VV = VWINDT * SIN(THETAW * PIE / 180!)
     '
     NE% = 5
     IF FB$ = "F" THEN NFPSEGS% = 0
     HF = CHBOT
     FOR I% = 1 TO NE%
     IF I% <= NFPSEGS% THEN DHF(I%) = FPLN(I%) ELSE DHF(I%) = HF / (NE% - NFPSEGS%)
     NEXT I%
     PELHT = HF + 3 * HF / (NE% - NFPSEGS%)
     HH = ABS(HT(19) - HT(15))
     FOR Y% = 1 TO NE%
       IF Y% > NFPSEGS% THEN GOTO 1647
       DIA(1, Y%) = (2 * SQR(AR(5) / PIE)): GOTO 1648
1647   DIA(1, Y%) = (2 * SQR(AR(2) / PIE))
1648   DI2(1, Y%) = (DIA(1, Y%) * PIE)
     NEXT Y%
     FOR ZZ% = 1 TO NE%: ELHT(ZZ%) = PELHT - HF / (NE% - NFPSEGS%): PELHT = ELHT(ZZ%): NEXT ZZ%
      REM
      REM : -----------HOUSE AIRTIGHTNESS CHARACTERISTICS-----------
      REM :
      REM
      REM : ---------------PHYSICAL DATA IS READ IN-------------
      REM
      CALL friction.factors ' (4000)
     REM     INITIATION OF WOOD BURNING CHARACTERISTICS
     CALL Ini.Character ' (25000)
      IF Z$ = "N" THEN GOTO 1760
      CALL Print.constants ' (15000)
1760  REM
      REM : ---------INITIAL TEMPERATURE PROFILES ARE READ IN------------
      REM
      CALL IniTempProfile ' (4500)
1762  REM
      REM
      REM  :                                   F2 - FULL FIRING RATE  IN  BTU/HR
      REM
     F$ = "NOT"
     FW = 0
      REM
      REM :-----------COMPETING FANS & FIREPLACE CHIMNEY FLOWS-------------
      REM
     FANM = (QF * RO(9)) / 1000
     FIRM = (FP * RO(9)) / 1000
     MCOMP = FANM + FIRM
      REM
     REM=====================================================================
     REM
     REM : INITIAL CONDITIONS FOR THE ITERATIVE PROCESS
     REM
     REM=====================================================================
     REM
      CALL Element.prop ' (8000)
      CALL IniConditions '(9510)
     Q6 = .022
     Q9 = .001
     Q1 = .026: ER1 = 2
     X3 = .01: ER3 = 2
     SCS = SCS - SEC: SCSCHRG = SCS
     THS = T9
     Z1 = Z2 - 1
      CALL LineSummary(0)
     IF FL1% = 1 THEN LOCATE 12, 32: COLOR 15, 0: PRINT "  CALCULATING  ": LOCATE 12, 32: COLOR 31, 0: PRINT "!": LOCATE 12, 46: PRINT "!": LOCATE 14, 32: COLOR 15, 0: PRINT "  PLEASE WAIT":  ELSE 3000
     THCOMBT = 0
     TRAD1 = 0
3000 REM=====================================================================
     REM
     REM  :    S T A R T   O F  E X E C U T I O N   L O O P
     REM
     REM=====================================================================
     REM
     S = 0
3060  S = S + 1
     SCS = SCS + SEC
     IF BRAND$ = "Y" THEN SCSCHRG = SCSCHRG + SEC
     IF BRAND$ = "Y" AND SCSCHRG > 450 THEN CALL Ini.Character: SCSCHRG = 0
     IF S > 25000 THEN S = 31
     IF FL1% = 1 THEN 3100 ELSE 3080
3080 REM CLS
     REM LOCATE 1,1 : PRINT USING"TIME = #####.#  (s)   TIME STEP = #.### (s)";SCS;SEC
3100 Z1 = Z1 + 1
      IF SCS >= FS AND F$ = "NOT" AND BRAND$ = "N" THEN F$ = "ON": TRING(2, NWE%) = 300!: TRING(1, NWE%) = 300: TRING(2, NWE%) = 300: TRADFL = TRING(2, NWE%): Z1 = 0: CALL Light.Wood '(19500)
      IF SCS >= FS AND F$ = "NOT" AND BRAND$ = "Y" THEN F$ = "ON": TRING(5, NWE%) = 300!: TRADFL = TRING(2, NWE%): Z1 = 0: CALL Light.Wood '(19500)
      REM
      REM :----------5000- CALCULATION OF MASS FLOWS USING "CONTINUITY", PRESSURES USING BERNOULLI +
      REM
     ITER = 0
3210  ITER = ITER + 1
      IF ITER > 100 THEN PRINT #2, "*** ITERATION CONVERGENCE PROBLEMS -- FLOW RATES OF THE LAST TIME STEP WILL BE USED": GOTO 3520
      CALL mass.flow ' (5000)
      CALL pressure.par '(6000)
      REM
      REM  :--------CONVERGENCE ROUTINES---------
      REM
     C1 = PB(5) + PB(10)
     IF ABS(C1) > 1E+11 THEN Q9 = .002: X3 = .003: ER3 = .16: Q6 = .02: Q1 = .026: ER1 = .2: GOTO 3210
      IF ABS(C1) < .001 THEN GOTO 3390
     Q2 = Q6: ER2 = C1
     IF ER1 = ER2 THEN Q9 = .002: X3 = .003: ER3 = .16: Q6 = .02: Q1 = .026: ER1 = .2: GOTO 3210
     Q6 = (Q2 * ER1 - Q1 * ER2) / (ER1 - ER2)
     Q1 = Q2: ER1 = ER2
      GOTO 3210
3390 C2 = PB(9) - PB(10)
     IF ABS(C2) > 1E+11 THEN Q9 = .002: X3 = .003: ER3 = .16: Q6 = .02: Q1 = .026: ER1 = .2: GOTO 3210
      IF ABS(C2) < .001 THEN GOTO 3520
     ER4 = C2: X4 = Q9
     IF ER3 = ER4 THEN Q9 = .002: X3 = .003: ER3 = .16: Q6 = .02: Q1 = .026: ER1 = .2: GOTO 3210
     Q9 = (X4 * ER3 - X3 * ER4) / (ER3 - ER4)
     X3 = X4: ER3 = ER4
      REM
      GOTO 3210
      REM
      REM :--------END OF CONVERGENCE ROUTINE--------
      REM
3520  Q6LAST = Q6: Q9LAST = Q9
      REM :----------OUTPUT OF CALCULATION RESULTS--------------
     REM
     GOSUB 18000
     IF SCS >= ST THEN CALL print.all: GOTO 3669
     CALL burn.rate ' (27000)
     CALL flue.heattransfer   '(9000)
     CALL check.display: IF FF2% = 1 THEN GOTO 3669
3662 GOTO 3060
      REM
      REM====================================================================
      REM   :   E N D    O F    E X E C U T I O N    L O O P
      REM====================================================================
     REM
3669 BEEP: SCSFLAG% = 1: IF FL1% = 1 THEN CALL screen.graphics ELSE 3670
3670 IF FL1% <> 1 THEN GOTO 3671 ELSE CLOSE #2: CLOSE #4: CLS : PRINT "WOODSIM PROGRAM TERMINATED": PRINT : END'CHAIN FLUEIN$ :REM ,energy.balance,ALL
3671 CLOSE #2: CLOSE #4: LOCATE 25, 1: COLOR 19, 0: INPUT "Press ENTER to end this simulation                                       "; A$: F$ = "NOT": CLS : PRINT "WOODSIM PROGRAM TERMINATED": PRINT : END':CHAIN FLUEIN$ :REM ,energy.balance,ALL
     END
'
4750  REM
      FOR X% = 1 TO 19
     RO(X%) = 353.6 / (TN(X%) + TA)
     NEXT
     GOTO 1762
     REM
     RETURN
'
'
'==========================================================================
'                  E N D   O F  C A L C U L A T I O N S
'==========================================================================
'
'
18000  REM===================================================================
       REM
       REM :        LINE SUMMARY OUTPUT FOR EACH CALCULATION INTERVAL
       REM
       REM===================================================================
       REM
       REM
      OO(1) = SCS
      OO(2) = FW / 1000
      OO(3) = TMASSL
      OO(4) = VF(18) * 1000
      OO(5) = VF(10) * 1000
      OO(6) = VF(5) * 1000
      OO(7) = VF(8) * 1000
      OO(8) = PB(3)
      OO(9) = TMF
      OO(10) = TN(17)
      OO(11) = TN(6)
      TT = 0: TQ = 0
      FOR Y% = 1 TO NE%
        TT = TT + TI(1, Y%)
        TQ = TQ + TI(2, Y%)
      NEXT Y%
      TT = TT / NE%
      TQ = TQ / NE%
      OO(12) = TT
      OO(13) = TI(1, NE%)
      OO(14) = TQ
      FE = 100 * (TWDRAD + TOTFLRAD) / (THCOMBT + .00001)
      IF ABS(FE) > 100 THEN FE = 100
      OO(15) = FE
      OO(16) = UF
      OO(17) = KE(4)
      CALL values.pr2   ' (19300)   'ASSIGN THE ARRAY OOW FOR PR2 FILE
      IF FL1% = 1 THEN CALL PLOTW: CALL check.display: IF FF2% = 1 THEN GOTO 3669
18325 IF SCS >= ST THEN GOTO 18328
      IF S <= 10 THEN GOTO 18328
      IF ABS((Z2 * INT((SCS / Z2) + .5)) - SCS) <= SEC / 2 THEN GOTO 18328 ELSE GOTO 18460: 'IF Z1<Z2 AND S%>11 THEN GOTO 18460
18328 Z1 = 0
      IF S <= 10 THEN SIMTIME = SCS ELSE SIMTIME = INT(SCS * 2 + .5) / 2
      OO(1) = SIMTIME
       IF P$ = "D" THEN GOTO 18400
      PRINT #2, USING "          #####.#"; SIMTIME;
      FOR X% = 1 TO 10
        PRINT #2, USING "        ###.###"; PB(X%);
      NEXT X%
      PRINT #2, " "
       GOTO 18460
18400 FOR X% = 1 TO 17
        IF X% = 3 THEN PRINT #2, USING "   #####.###"; OO(X%);  ELSE PRINT #2, USING "   #######.#"; OO(X%);
      NEXT X%
      'FOR X% = 1 TO NE%
      '  PRINT #2, USING" ###.#";TI(2,X%);
      'NEXT X%
       PRINT #2, ""
       REM: IND10=1 : CALL print1: IND10 = 0
      FOR X% = 1 TO 18
        PRINT #4, USING "   #######.#"; OOW(X%);
      NEXT X%
      PRINT #4, ""
18460 RETURN
'
'
29000 REM *** USER ERROR HANDLING ROUTINES ***
      REM:  ERROR HANDLING ROUTINES
      SCREEN 0: COLOR 7
      IF ERR = 27 OR ERR = 24 THEN LOCATE 20, 40: PRINT "CHECK PRINTER": RESUME
      IF ERR = 61 THEN LOCATE 10, 40: PRINT "DISK IS FULL - USE ANOTHER DISKETTE": LOCATE 20, 1: PRINT SPACE$(79): PRINT SPACE$(79): RESUME 4750
      IF ERR = 5 AND ERL = 21020 THEN GOTO 35000
      CLOSE
      CLS : PRINT USING "PROBLEMS...  Error detected...  Error ###,  Nearest Line ######"; ERR; ERL: STOP
29600 '   PRINT FINAL ENERGY STATE AT END OF TIME STEP
      RETURN
'
'
35000 BEEP: CLS : LOCATE 5, 5: PRINT "You have chosen 'GRAPH' output and the 'WINSTAL2.DAT' file"
      LOCATE 7, 5: PRINT "indicates that your computer is capable of 640x200"
      LOCATE 9, 5: PRINT "resolution graphics, but this is not the case for"
      LOCATE 11, 5: PRINT "the present configuration"
      LOCATE 14, 5: PRINT "DO YOU WISH TO -"
      LOCATE 16, 1: PRINT "1. RETURN to the main menu to SAVE the current input data, then EXIT to DOS "
      LOCATE 18, 1: PRINT "2. RUN the INSTALLW program to correct 'WINSTAL5.DAT'"
      LOCATE 22, 10: INPUT "Your choice  1, 2 or [3]"; A%
      IF A% = 1 THEN GOTO 3671
      IF A% = 2 THEN RUN "INSTALLW"
      FL1% = 0: GD$ = "T": CLS : RESUME 18325'SET UP FOR TABLES

SUB screen.graphics STATIC
'==========================================================================
'
'                 SCREEN GRAPHICS PRINT OPTION (3675)
'
'==========================================================================
        'LPRINT "ENTERING screen.graphics"
3675 FF1% = 0: LOCATE 1, 13: PRINT "Press 'P' for PRINT, 'S' for SAVE"
     LOCATE 2, 13: IF SCS >= ST THEN PRINT "'E' for EXIT          " ELSE PRINT "'E' for EXIT or 'C' to CONTINUE"
3677 JUNK$ = INKEY$: IF JUNK$ = "" THEN 3677
     IF JUNK$ = "E" OR JUNK$ = "e" THEN 3696 ELSE 3679
3679 IF JUNK$ = "P" OR JUNK$ = "p" THEN JUNK$ = "P": GOTO 3690 ELSE 3680
3680 IF JUNK$ = "S" OR JUNK$ = "s" THEN 3690 ELSE 3681
3681 IF JUNK$ = "C" OR JUNK$ = "c" THEN 3682 ELSE 3677
3682 LOCATE 1, 13: PRINT "                                 "
     LOCATE 2, 13: PRINT "                                 "
     FF1% = 1: GOTO 3697
3690 LOCATE 1, 13: PRINT USING "\                                  \"; TITLE$
     LOCATE 2, 13: PRINT USING "DATE: \                        \"; DATE$
     IF JUNK$ = "P" THEN CALL PRTSC: GOTO 3696: REM:  ASM=-51973.8
     CHK$ = ".": LOCDOT = INSTR(DOC$, CHK$): FAULT$ = LEFT$(DOC$, LOCDOT - 1): REM:  PRTSCR%=VARPTR(ASM)
     DEF SEG = &HB800: BSAVE DRIVE$ + FAULT$ + ".PIC", 0, 16384: DEF SEG :     REM:  CALL ABSOLUTE(PRTSCR%)
3696 CLS : SCREEN 0, 0
3697 REM
        'LPRINT "LEAVING screen.graphics"
END SUB

SUB screen.setup STATIC

'==========================================================================
'   SCREEN SETUP FOR DISPLAY 3-TEMPERATURE DISTRIBUTION IN LOGS (32613)
'==========================================================================
      '
      '
      'LPRINT "ENTERING screen.setup"
      LOCATE 1, 1: PRINT "TIME    HEAT    TEMPERATURE    WOOD ELEMENT TEMP-->"
                 PRINT "        COMB  CH.GAS CH.LINER"
                 PRINT " (s)    (kW)    (C)   (C)      (C).....            "
      PRINT
      LOCATE 4, 28: FOR I% = 1 TO NT%: PRINT USING "  ## "; I%; : NEXT
      PRINT : PRINT
      LOCATE 6, 1
      PRINT USING "#####.#"; SCS;
      PRINT USING " #### "; HCOMBT / (1000 * TSTEP);
      IF TN(6) < 0 THEN CLS : PRINT MF(6), MF(11), MF(18): PRINT TN(11), TN(18): STOP
      PRINT USING "  #### "; TT;  ' TN(6);
      PRINT USING " #### "; TQ;
       FOR J% = NWE% TO 1 STEP -1
      LOCATE 11 - J%, 28
      FOR I% = 1 TO NT%
      IF MRING(I%, J%) <= 0 THEN PRINT "     "; : GOTO 32710
      PRINT USING "#### "; TRING(I%, J%);
32710 NEXT
      PRINT
      NEXT J%
      LOCATE 12, 1: PRINT USING "OPENING TEMP       =  ###.# (C)"; TWALL(5, 1); : PRINT USING "               FLUE FLOW      = ####.# L/s"; VF(5) * 1000
      LOCATE 13, 1: PRINT USING "BACK WALL TEMP     =  ###.# (C)"; TWALL(2, 1); : PRINT USING "               DILUTION FLOW  = ####.# L/s"; VF(10) * 1000
      LOCATE 14, 1: PRINT USING "SIDE WALLS TEMP    =  ###.# (C)"; TWALL(1, 1); : PRINT USING "               HOUSE PRESSURE = ####.# Pa "; PB(3)
      LOCATE 15, 1: PRINT USING "FLAME AREA         =    #.#### (m2)"; ARFLAME
      'LOCATE 16,1 : PRINT USING"FLOOR OR ASHES TEMP=  ###.# (C)";TWALL(4,1)
      LOCATE 17, 1: PRINT USING "TOTAL ENERGY RELEASED= ##.### kWh"; THCOMBT / 3600000!;
      LOCATE 18, 1: PRINT USING "HEAT TRANSF. TO HOUSE= ##.### kWh"; CUMWDRAD(5) / 3600000!;
      LOCATE 19, 1: PRINT USING "EFFICIENCY           =  ###.# %  "; FE;
      LOCATE 20, 1: PRINT USING "MASS OF WOOD BURNED  = ##.### kg  ----> ###.#%  OF THE ORIGINAL ##.### kg"; TMASSB; (TMASSB * 100 / TMASS); TMASS
      LOCATE 21, 1: PRINT USING "MASS OF WOOD LEFT    = ##.### kg  "; TMASSL;
      PWMOIST = 100 - ((TDMASSL + 1E-09) * 100 / (TMASSL + 1E-09)): IF ABS(PWMOIST) > 100 THEN PWMOIST = 0
      PGMOIST = (100 - (100 * (TDBURNED + 1E-09) / (TMASCOMB + 1E-09))): IF ABS(PGMOIST) > 100 THEN PGMOIST = 0
      LOCATE 22, 1: PRINT USING "RESIDUAL MOISTURE    =  ###.# %       MOISTURE IN PYROLYZED GAS   = ###.# %   "; PWMOIST; PGMOIST
      IF TMASCOMB > 0 AND TMASSL > 0 THEN TLB = (TMASSL / (60 * (TMASCOMB + 1E-08) / TSTEP)) ELSE TLB = 0
      LOCATE 23, 1: PRINT USING "ELAPSED TIME         =#####.# min     ESTIMATED TIME LEFT TO BURN =###### min "; SCS / 60; TLB
      LOCATE 25, 1: PRINT "(press E for the energy balance screen, T for the wall temperatures screen)";
        'LPRINT "LEAVING screen.sutup"
END SUB

STATIC SUB burn.rate ()
'==========================================================================
'             ENERGY UPDATE IN THE WOODBURNING MODULE  (27000)
'             ESTABLISH THE BURN RATE OF EACH ELEMENT
'             AND CORRESPONDING ENERGY PRODUCED BY COMBUSTION
'
'             FINDING CANDIDATE WOOD MASS ( WITH TEMP ABOVE 204 C)
'==========================================================================
      'LPRINT "ENTERING burn.rate"
      TSTEP = SEC
      TMASCOMB = 0
      TMCP = 0
      FOR I% = 1 TO NT%
        MRINGL(I%) = 0!
        FOR J% = NWE% TO 1 STEP -1
          MRINGL(I%) = MRINGL(I%) + MRING(I%, J%): CPLOG(I%, J%) = HCRING(I%, J%) * (.908 + .0046 * TRING(I%, J%))
        NEXT J%
        FOR J% = NWE% TO 1 STEP -1
          MASCOMB(I%, J%) = 0
          IF INDCOMB% = 0 THEN 27150
          IF TRING(I%, J%) < 204 THEN GOTO 27150
          IF MRING(I%, J%) <= 0 THEN GOTO 27150
          IF MRINGL(I%) <= (UNBURND * OMRING(I%) / 100) THEN 27150
          IF J% < NWE% THEN
            IF MRING(I%, J% + 1) > 0 THEN GOTO 27150
          END IF
          MASCOMB(I%, J%) = MRING(I%, J%)
          TMASCOMB = TMASCOMB + MRING(I%, J%)
27150   NEXT J%
      NEXT I%
      '
      '        ACTUAL RATE OF COMBUSTION AS LIMITED BY AIR SUPPLY IN PILE
      '
      TROOM = T9
      IF INTAKE$ = "Y" AND SCS > CDT THEN TINTAKE = TN(1) ELSE TINTAKE = TROOM
      MFAIR = ABS(MF(15))
      IF INTAKE$ = "Y" AND SCS > CDT THEN FRACOMB = .25 ELSE FRACOMB = .25
      'MAXWD=TSTEP*MFAIR*FRACOMB/STOICHAIR
      'MRATE= MAXWD/(TMASCOMB+1E-09)
      'IF MRATE > 1 THEN MRATE = 1
      '
      ' ACTUAL RATE OF COMBUSTION FOR EACH ELEMENT
      TMASSL = 0
      TMASCOMB = 0
      HCOMBT = 0
      TBSURF = 0
      TDMASSL = 0
      TDBURNED = 0
      FOR I% = 1 TO NT%
      TMRING(I%) = 0
      FOR J% = NWE% TO 1 STEP -1
      IF MASCOMB(I%, J%) = 0 THEN HCOMB(I%, J%) = 0: GOTO 27390
      TBRATE = BRATE * ABS(VF(16)) * 1000 * FRACOMB: REM   IF TBRATE > TBRLIMIT THEN TBRATE = TBRLIMIT
      IF I% > NPS% THEN EXPOSURE = .75 ELSE EXPOSURE = 1!
      MASCOMB(I%, J%) = TBRATE * TSTEP * ARING(I%, J%) * EXPOSURE
      TBSURF = TBSURF + ARING(I%, J%) * EXPOSURE
      IF (MRING(I%, J%) - MASCOMB(I%, J%)) < 0 THEN MASCOMB(I%, J%) = MRING(I%, J%): MRING(I%, J%) = 0: TOPRING%(I%) = J% - 1: GOTO 27350
      MRING(I%, J%) = MRING(I%, J%) - MASCOMB(I%, J%)
27350 TMASCOMB = TMASCOMB + MASCOMB(I%, J%)
      TMCP = TMCP + MASCOMB(I%, J%) * CPLOG(I%, J%)
27390 TMASSL = TMASSL + MRING(I%, J%)
      TMRING(I%) = TMRING(I%) + MRING(I%, J%)
      NEXT J%
      NEXT I%
      TMASSB = TMASS - TMASSL
      ' HEAT RELEASE AS A FUNCTION OF DRY WOOD BURNED
      FOR I% = 1 TO NT%
      WBURNED = 100 * (OMRING(I%) - TMRING(I%)) / OMRING(I%)
      DRYLEFT = TMRING(I%) * (1 - (MCONTENT(I%) / 100) * EXP(-.0129 * WBURNED))
      DBURNED = DRYMAS(I%) - DRYLEFT
      TDBURNED = TDBURNED + DBURNED
      DRYMAS(I%) = DRYLEFT
      TDMASSL = TDMASSL + DRYMAS(I%)
      FOR J% = 1 TO NWE%
      IF MASCOMB(I%, J%) = 0 THEN HCOMB(I%, J%) = 0: GOTO 27426
      IF I% <= NPS% THEN HCOMB(I%, J%) = DBURNED * HEATSOFT ELSE HCOMB(I%, J%) = DBURNED * HEATHARD
27426 HCOMBT = HCOMBT + HCOMB(I%, J%)
      THCOMBT = THCOMBT + HCOMB(I%, J%)
      NEXT J%
      NEXT I%
      '      SHIFTING THE LAST PORTION OF WOOD MASS TO THE NEXT ELEMENT
      FOR I% = 1 TO NT%
      FOR J% = NWE% TO 1 STEP -1
      IF TRING(I%, J%) > 700 AND NWE% = J% THEN GOTO 27470
      IF TRING(I%, J%) > 700 AND NWE% < J% THEN
         IF MRING(I%, J% + 1) <= 0 THEN GOTO 27470
      END IF
      IF (.4 * MRING(I%, J%) * CPLOG(I%, J%)) / (URING(I%, J%) * ARING(I%, J%)) > TSTEP THEN GOTO 27540
27470 IF MRING(I%, J%) = 0 THEN GOTO 27540
      IF J% = 1 AND MRING(I%, J%) <= OMRING(I%) THEN GOTO 27540
      I1% = I%: J1% = J% - 1: IF J% = 1 AND I% < NT% THEN I1% = I% + 1: J1% = NWE%
      IF MRING(I%, J% + 1) > 0 AND J% = 1 THEN CLS : PRINT USING "LOG  ##  IS TOO SMALL FOR THE TIME STEP"; I%: END
      INDCOMB% = 1
27500 IF I% = NT% AND J% = 1 THEN I1% = I1% - 1: IF MRING(I1%, 1) <= 0 THEN GOTO 27500: 'INDCOMB%=0:GOTO 27590
      MTEMP = 0
      IF J% = 1 AND MRING(I%, J%) > OMRING(I%) THEN MTEMP = OMRING(I%): MRING(I%, J%) = MRING(I%, J%) - OMRING(I%)
      TRING(I1%, J1%) = -TA + (((TRING(I%, J%) + TA) * MRING(I%, J%)) + ((TRING(I1%, J1%) + TA) * MRING(I1%, J1%))) / (MRING(I%, J%) + MRING(I1%, J1%))
      MRING(I1%, J1%) = MRING(I1%, J1%) + MRING(I%, J%)
      MRING(I%, J%) = MTEMP
      TOPRING%(I%) = J1%
27540 NEXT J%
      NEXT I%
      '          UPDATE HEAT INPUT & NEW TEMPERATURES OF THE LOG ELEMENTS
      '
      '          SUM UP THE HEAT BACK INTO EACH LOG & HEAT INTO THE AIR
27590 HEATAIR = 0
      FOR I% = 1 TO NT%
        HEATIN(I%) = 0
      NEXT I%
      FOR I% = 1 TO NT%
      FOR J% = NWE% TO 1 STEP -1
      IF HCOMB(I%, J%) = 0 THEN GOTO 27710
      '
      IF TRING(I%, TOPRING%(I%)) < 900 THEN HEATIN(I%) = HEATIN(I%) + HCOMB(I%, J%) * PWR ELSE HEATAIR = HEATAIR + HCOMB(I%, J%) * PWR
      FOR II% = 1 TO NCOEF%(I%)
      IF TRING(INCOEF%(I%, II%), TOPRING%(INCOEF%(I%, II%))) < 900 THEN HEATIN(INCOEF%(I%, II%)) = HEATIN(INCOEF%(I%, II%)) + ((HCOMB(I%, J%) * PAW)) ELSE HEATAIR = HEATAIR + ((HCOMB(I%, J%) * PAW))
      NEXT II%
      HEATAIR = HEATAIR + HCOMB(I%, J%) * (1 - PWR - (NCOEF%(I%) * PAW)) + (MASCOMB(I%, J%) * CPLOG(I%, J%) * (TRING(I%, J%) - TINTAKE))
27710 NEXT J%
      NEXT I%
      REM LOCATE 16,1:FOR I% = 1 TO NT% : PRINT HEATIN(I%),:NEXT:PRINT HEATAIR
      '          UPDATE OF LOG TEMPERATURES
      FOR I% = 1 TO NT%
      FOR J% = TOPRING%(I%) TO 1 STEP -1
      TRF(I%, J%) = TRING(I%, J%)
      JP1% = J%
      IF J% < NWE% THEN
        IF MRING(I%, J% + 1) > 0 THEN JP1% = J% + 1
      END IF
      IF MRING(I%, J%) <= 0 THEN TRF(I%, J%) = TFLAME: GOTO 27840
      IF MRING(I%, J%) > 0 AND HEATIN(I%) > 0 THEN HIN = HEATIN(I%): HEATIN(I%) = 0: GOTO 27830
      HIN = TSTEP * ARING(I%, J%) * URING(I%, J%) * (TRING(I%, JP1%) - TRING(I%, J%))
      TRF(I%, JP1%) = TRF(I%, JP1%) - (HIN / (MRING(I%, J%) * CPLOG(I%, J%)))
27830 TRF(I%, J%) = TRF(I%, J%) + (HIN / (MRING(I%, J%) * CPLOG(I%, J%)))
27840 NEXT J%
      NEXT I%
      FOR I% = 1 TO NT%
      FOR J% = 1 TO NWE%
      IF TRF(I%, J%) > 1500 THEN TRF(I%, J%) = 1500
      TRING(I%, J%) = TRF(I%, J%)
      NEXT J%: NEXT I%
      CALL energy.balance
      '
      '     RADIATION HEAT TRANSFER
28130 '          NET HEAT GIVEN OFF TO THE AIR STREAM
      MT1AIR = (TSTEP * MFAIR * FRACOMB) + TMASCOMB
      MT2AIR = TSTEP * MFAIR + TMASCOMB
      TRISE1 = QFLUE / (TSTEP * MFAIR * FRACOMB * CPAIR + TMCP)
      SURFCONV = 0: FOR SURFACE% = 1 TO 6: SURFCONV = SURFCONV + QCONV(SURFACE%): NEXT SURFACE%
      IF (QFLUE + SURFCONV) < 0 THEN SURFCONV = -QFLUE
      TRISE2 = (QFLUE + SURFCONV) / (TSTEP * MFAIR * CPAIR + TMCP)
      TFLAME = TINTAKE + TRISE1
      T9 = TROOM: 'T9=TS(1)
      TSTACK = TINTAKE + TRISE2
      TN(16) = TFLAME: TN(17) = TSTACK: TN(18) = TN(17)
      REM : TMF=(TWALL(1,1)+TWALL(2,1)+TWALL(3,1)+TWALL(4,1)+TWALL(6,1))/5
      TMF = TWALL(2, 1)
      REM
      REM
      IF MF(6) = 0 THEN GOTO 28212
      TN(6) = ((ABS(MF(18)) * CPAIR * (TN(18) + TA)) + (ABS(MF(11)) * CPAIR * (TN(11) + TA))) / (ABS(MF(6)) * CPAIR)
      IF MF(11) < 0 THEN TN(6) = TN(18) + TA
      IF MF(11) < 0 AND MF(6) < .0000001 THEN TN(6) = ((ABS(MF(18)) * (TN(18) + TA)) + (ABS(MF(5)) * (TN(4) + TA))) / (ABS(MF(18)) + ABS(MF(5)))
28212 IF MF(15) < 0 THEN TN(6) = (TN(4) + TA)
      TN(6) = TN(6) - TA
      TN(19) = TN(6): TN(12) = TN(6)
       IF MF(5) > 0 THEN TN(5) = TN(6) ELSE TN(5) = TN(4)
      TN(11) = T9
       IF MF(11) < 0 THEN TN(11) = TN(6)
       IF MF(17) < 0 THEN TN(18) = TN(6)
      FW = HCOMBT / TSTEP

        'LPRINT "LEAVING burn.rate"
END SUB

STATIC SUB check.display ()
'==========================================================================
'
' CHECK WHICH SCREEN DISPLAY IS REQUESTED-SKIP IF GRAPHICS DISPLAY IS ON (31622)
'
'==========================================================================
      'LPRINT "ENTERING check.display"
      FF2% = 0
       KB$ = INKEY$
       IF KB$ = "" THEN KB$ = " "
       IF KB$ = "a" OR KB$ = "A" THEN FF2% = 1: GOTO 31655
       IF FL1% = 1 THEN GOTO 31655
       IF KB$ = "e" OR KB$ = "E" THEN NDISPLAY% = 2: KB$ = " ": GOTO 31648
       IF KB$ = "t" OR KB$ = "T" THEN NDISPLAY% = 1: KB$ = " ": GOTO 31648
       IF KB$ = "s" OR KB$ = "S" THEN NDISPLAY% = 3: KB$ = " ": GOTO 31648
       IF KB$ = "x" OR KB$ = "X" THEN ETRAP = 1: CLS : GOTO 31655
       IF KB$ = "c" OR KB$ = "C" THEN ETRAP = 0:
      GOTO 31649
31648 IF NDISPLAY% <> DISPLAY% THEN DISPLAY% = NDISPLAY%: CLS
31649 IF DISPLAY% = 1 THEN CALL display1.screen
      IF DISPLAY% = 2 THEN CALL display2.screen
      IF DISPLAY% = 3 THEN CALL screen.setup
31655 REM
        'LPRINT "LEAVING check.display"
END SUB

STATIC SUB display1.screen ()
'==========================================================================
'    SCREEN SETUP FOR DISPLAY 1  (31860)
'   -PRINTOUT OF TEMPERATURE MATRIX OF FIREPLACE/WOODSTOVE
'==========================================================================
      'LPRINT "ENTERING display1.screen"
      LOCATE 1, 1: PRINT "     TEMPERATURE PROFILES FOR EACH WALL OF THE FIREPLACE ENCLOSURE"
      LOCATE 2, 17: PRINT "RADIANT TEMPERATURES FROM WOOD"
      LOCATE 3, 1: FOR I% = 1 TO NT%: PRINT USING "  ###  "; I%; : NEXT I%
      LOCATE 4, 1: FOR I% = 1 TO NT%: J% = ORN%(I%): PRINT USING "#####.#"; TRING(I%, J%); : NEXT I%
      LOCATE 5, 30: PRINT USING "#####.#"; TRADFL
      'J%= ORN%(I):FLAMET=TRADFL:IF TRING(I,J%)=<9 THEN FLAMET=0
      'PRINT USING"#####.#";TRADFL
      'NEXT I
      LOCATE 6, 1: PRINT "FIREBOX SURFACE------------------------------------------------>SURROUNDINGS"
      LOCATE 7, 30: PRINT "SIDE WALLS "
      LOCATE 10, 30: PRINT "BACK WALL "
      LOCATE 13, 30: PRINT "FLOOR "
      LOCATE 16, 30: PRINT "FRONT FACE"
      LOCATE 19, 30: PRINT "TOP OF FIREBOX": 'OR ANY OTHER SURROUNDING TO INVESTIGATE
      FOR SECTION% = 1 TO 11
        FOR SURFACE% = 1 TO 6
        IF SURFACE% = 3 THEN GOTO 32030
        IF SURFACE% > 3 THEN XS% = 5 + 3 * (SURFACE% - 1) ELSE XS% = 5 + 3 * SURFACE%
        LOCATE XS%, (SECTION% - 1) * 7 + 2: PRINT USING "  ###  "; SECTION%;
        LOCATE XS% + 1, (SECTION% - 1) * 7 + 1: PRINT USING "  ###.#"; TWALL(SURFACE%, SECTION%);
32030   NEXT SURFACE%
      NEXT SECTION%
      LOCATE 23, 1: PRINT "PRESS E FOR ENERGY BALANCE,S FOR SUMMARY-->"; : PRINT KB$: LOCATE 23, 55: PRINT USING "ELAPSED TIME(s) #####"; SCS
        'LPRINT "LEAVING display1.screen"
END SUB

STATIC SUB display2.screen ()
'==========================================================================
'
'                   SCREEN SETUP UP FOR DISPLAY 2  (32123)
'          -ENERGY BALANCE FOR WOOD PILE AND SURROUNDING SURFACES
'
'==========================================================================
      'LPRINT "ENTERING display2.screen"
      LOCATE 1, 1: PRINT "CUMULATIVE ENERGY DISTRIBUTION FOR FIREPLACE/WOODSTOVE SYSTEM(Wh)"
      LOCATE 2, 1: PRINT USING "HEATAIR=######.##"; SOURCEQ / 3600
      LOCATE 2, 20: PRINT USING "FLUE=#####.## "; TQFLUE / 3600
      LOCATE 2, 35: PRINT USING "FLAME RAD=######.##"; TOTFLRAD / 3600
      LOCATE 2, 55: PRINT USING "WOOD RAD=#######.##"; TWDRAD / 3600
      '
      'ENERGY DISTRIBUTION FOR EACH SURFACE AND ELEMENT OF WALL
      '
      LOCATE 3, 1: PRINT "ENERGY BALANCE FOR EACH SURFACE"
      LOCATE 5, 1: PRINT "TOTAL RAD"
      LOCATE 6, 1: PRINT "SURF. RAD"
      LOCATE 7, 1: PRINT "TOTAL RAD"
      LOCATE 8, 1: PRINT "SURF CONV"
      LOCATE 9, 1: PRINT "NET ENRGY"
      LOCATE 11, 1: PRINT "FIREBOX": LOCATE 20, 1: PRINT "EXTERIOR"
      LOCATE 10, 1: PRINT "TOTAL ENERGY STORED IN EACH ELEMENT OF ENCLOSURE"
      LOCATE 21, 1: PRINT "RADIAT'N"
      LOCATE 22, 1: PRINT "CONVECT'N"
      FOR SURFACE% = 1 TO 6
      LOCATE 4, SURFACE% * 10: PRINT USING " #######    "; SURFACE%
      LOCATE 5, SURFACE% * 10: PRINT USING " ######.## "; CUMWDRAD(SURFACE%) / 3600
      LOCATE 6, SURFACE% * 10: PRINT USING " ######.## "; SURFRAD(SURFACE%) / 3600
      LOCATE 7, SURFACE% * 10: PRINT USING " ######.## "; TOTRAD(SURFACE%) / 3600
      LOCATE 8, SURFACE% * 10: PRINT USING " ######.## "; -TOTCONV(SURFACE%) / 3600
      LOCATE 9, SURFACE% * 10: PRINT USING " ######.## "; NETRAD(SURFACE%) / 3600
      FOR SECTION% = 1 TO 10
      LOCATE SECTION% + 10, SURFACE% * 10: PRINT USING " ######.## "; TOTSTOR(SURFACE%, SECTION%) / 3600
      NEXT SECTION%
      LOCATE 21, SURFACE% * 10: PRINT USING " ######.## "; TOTCONDOUT(SURFACE%) / 3600
      LOCATE 22, SURFACE% * 10: PRINT USING " ######.## "; EXTCONV(SURFACE%) / 3600
      NEXT SURFACE%
      LOCATE 23, 1: PRINT "PRESS T FOR WALL TEMP, S FOR SUMMARY-->"; : PRINT KB$: LOCATE 23, 55: PRINT USING "ELAPSED TIME(s) #####"; SCS
        'LPRINT "LEAVING display2.screen"
END SUB

STATIC SUB Element.prop ()
'==========================================================================
'
'     SPECIFICATION OF ELEMENTAL PROPERTIES OF THE FLUE & THE FIREBOX (8000)
'
'==========================================================================
      'LPRINT "ENTERING element.prop"
      REM
      FOR Y% = 1 TO NE%
     U(1, Y%) = 1! / ((1! / UI) + (.5 / THCL(Y%)))
     IF THCS(Y%) = 0! THEN U(2, Y%) = 1! / ((1! / 8.3) + (.5 / THCL(Y%))) ELSE U(2, Y%) = 1! / ((.5 / THCS(Y%)) + (.5 / THCL(Y%)))
     IF THCS(Y%) = 0! OR THCO(Y%) = 0! THEN U(3, Y%) = 8.33 ELSE U(3, Y%) = 1! / ((.5 / THCS(Y%)) + (.5 / THCO(Y%)))
     IF THCO(Y%) = 0! THEN U(3, Y%) = 8.33 ELSE U(4, Y%) = 1! / ((.5 / THCO(Y%)) + (1! / 8.3))
     REM
     REM:----------ALL  "M"  "HC" "A" TO BE SPECIFIED HERE-----------
     REM
     FOR J% = 1 TO 4
       IF DI2(J%, Y%) = 0 THEN A(J%, Y%) = A(J% - 1, Y%): GOTO 8170
       IF Y% < (NFPSEGS% + 1) THEN A(J%, Y%) = DHF(Y%) * DI2(J%, Y%): GOTO 8170
       A(J%, Y%) = HF * DI2(J%, Y%) / (NE% - NFPSEGS%)
8170 NEXT J%
     REM:A(1,Y%)=A(2,Y%)*.98
     HC(1, Y%) = CPAIR
     REM
     M(2, Y%) = DENL(Y%) * A(2, Y%) * ELTL(Y%)
     M(3, Y%) = DENS(Y%) * A(3, Y%) * ELTS(Y%)
     M(4, Y%) = DENO(Y%) * A(4, Y%) * ELTO(Y%)
     NEXT Y%
      REM
      REM: -----------SPECIFICATION OF FLUEPIPE PROPERTIES-------------
      REM
     FOR Y% = 1 TO NFPSEGS%
       IF M(3, Y%) = 0 THEN M(3, Y%) = M(3, NE%): U(3, Y%) = U(3, NE%): HC(3, Y%) = HC(3, NE%): FPI$ = "U"
       IF M(4, Y%) = 0 THEN M(4, Y%) = M(4, NE%): U(4, Y%) = U(4, NE%): HC(4, Y%) = HC(4, NE%): FPI$ = "U"
     NEXT Y%
     REM
     REM:----------------CHECK OF TIME CONSTANTS-------------------
     REM
     GOTO 8460
      CLS : PRINT "OUTFLOW TIME CONSTANTS OF CHIMNEY ELEMENTS FROM LINER TO SURROUNDINGS:": PRINT
      FOR J% = 2 TO 4
     TZ = (M(J%, NE%) * HC(J%, NE%)) / (U(J%, NE%) * A(J%, NE%)): REM:NOTE NE% WAS ORIGINALLY 5,THE VALUE OF 5 WAS ARBITRARY-MCS.
      PRINT USING "FROM POINT ##  TO POINT ## :  ######."; J%; J% + 1; TZ
      NEXT J%
      PRINT :  PRINT "INFLOW TIME CONSTANTS OF CHIMNEY ELEMENTS FROM LINER TO SURROUNDINGS:": PRINT
      FOR J% = 2 TO 4
     TZ = (M(J%, NE%) * HC(J%, NE%)) / (U(J% - 1, NE%) * A(J% - 1, NE%)): REM SAME COMMENT ABOUT NE% AS LINE 8380
      PRINT USING "FROM POINT ##  TO POINT ## :  ######."; J% - 1; J%; TZ
      NEXT J%
     T = TIMER: WHILE TIMER < T + 3: WEND
8460  REM
      REM :-------------FIREBOX PHYSICAL PROPERTIES----------------
      REM
        'LPRINT "LEAVING element.prop"
END SUB

STATIC SUB energy.balance ()
'==========================================================================
'    SUBROUTINE TO CALCULATE ENERGY BALANCE OF FIREBOX ENCLOSURE (30000)
'            1-LEFT SIDE
'            2-BACK SIDE
'            3-RIGHT SIDE
'            4-FLOOR OF FIREBOX
'            5-ROOM SURROUNDINGS
'            6-TOP OF FIREPLACE OR TOP OF WOODSTOVE
'==========================================================================
      'LPRINT "ENTERING energy.balance"
      IF FL1% <> 1 AND setup% = 0 THEN CLS : DISPLAY% = 3: NDISPLAY% = 1
'
'  PROPERTIES OF WOOD
'
      FOR I% = 1 TO NT%
      FOR J% = NWE% TO 1 STEP -1
      IF setup% = 0 THEN EMISSW(I%) = .8: TFLAME2 = 300!: J% = 1
      IF MRING(I%, J%) <= 0 THEN GOTO 30570
      IF MRING(I%, J%) > 0 AND TRING(I%, J%) <= 204 THEN J% = 1
      IF MRING(I%, J%) > 0 AND TRING(I%, J%) > 204 THEN TBSURF = TBSURF + ARING(I%, J%): J% = 1
30570 NEXT J%
      NEXT I%
      setup% = 1
'
'   PERFORM ENERGY BALANCE ON ENCLOSURE
'
      QWTO5 = 0: QFTO5 = 0: QSTO5 = 0: QTRAN = 0
      FOR I% = 1 TO NT%
      FOR J% = NWE% TO 1 STEP -1
      IF J% < NWE% THEN
        IF MRING(I%, J% + 1) > 0! THEN J% = 1: GOTO 31177
      END IF
      IF MRING(I%, J%) <= 0 THEN GOTO 31177
      ORN%(I%) = J%: MRINGO(I%) = MRING(I%, J%): BOUNDFND = 0: GUESS1 = 0
'
'   SUM ALL RADIATION THAT FALLS ON EACH SURFACE FROM WOOD
'
      WOODRAD(I%) = 1E-34
      FOR SURFACE% = 1 TO 6
      IF MRING(I%, J%) <= 0 THEN GOTO 31170
      QRADW(I%, SURFACE%) = TSTEP * EMISS(SURFACE%) * EMISSW(I%) * RFRACTS(I%) * SBCONST * ((TRING(I%, J%) + 273.15) ^ 4 - (TWALL(SURFACE%, 1) + 273.15) ^ 4) * ARING(I%, J%) * FRWDS(SURFACE%)
      WOODRAD(I%) = WOODRAD(I%) + QRADW(I%, SURFACE%)
      IF GLASSDR$ = "Y" AND SURFACE% = 5 THEN QWTO5 = QWTO5 + TSTEP * TRANSMISS(5) * SBCONST * ARING(I%, J%) * RFRACT(I%) * FRWDS(5) * ((EMISSW(I%) * ((TRING(I%, J%) + 273.15) ^ 4)) - ((TWALL(5, 11) + 273.15) ^ 4)): 'TRANSMISSION EQUATION
31170 NEXT SURFACE%
      '
      'UPDATE TEMPERATURE OF OUTER RING AFTER RADIATION
      DT1RAD = WOODRAD(I%) / (MRING(I%, J%) * CPLOG(I%, J%)): IF ABS(DT1RAD) > 10 THEN DT1RAD = 10 * DT1RAD / ABS(DT1RAD)
      TRING(I%, J%) = TRING(I%, J%) - DT1RAD
      ' CHECK TO SEE IF COMBUSTION HAS OCCURED-SOLVE THE STEADY STATE FLAME TEMPERATURE
31177 NEXT J%
      NEXT I%
      IF HEATAIR <= 0 THEN FLAMERAD = 0: QFLUE = 0: GOTO 31290
      TRADFL = 1200: 'TFLAME2
31181 ARFLAME = HEATAIR * .007 / (TSTEP * 3600): FLAMERAD = 1E-34
      FOR SURFACE% = 1 TO 6
      QRADFL(SURFACE%) = TSTEP * EMISS(SURFACE%) * SBCONST * ((TRADFL + 273.15) ^ 4 - (TWALL(SURFACE%, 1) + 273.15) ^ 4) * ARFLAME * FRWS(SURFACE%)
      IF GLASSDR$ = "Y" AND SURFACE% = 5 THEN QFTO5 = TSTEP * TRANSMISS(5) * SBCONST * ARFLAME * FRWS(5) * (((TRADFL + 273.15) ^ 4) - (TWALL(5, 11) + 273.15) ^ 4): 'TRANSMISSION EQUATION
      FLAMERAD = FLAMERAD + QRADFL(SURFACE%)
      NEXT SURFACE%
      QFLUE = HEATAIR - FLAMERAD: REM TSTEP*MFAIR*FRACOMB*CPAIR*(TRADFL-TINTAKE)
      GOTO 31290: REM JUMP OVER THE FLAME TEMP CALC
      QBALANCE = HEATAIR - FLAMERAD - QFLUE
      IF ETRAP = 0 THEN GOTO 31216 ELSE GOTO 31210
31210 CLS : PRINT " HEATAIR;FLAMERAD;QFLUE;QBALANCE;QBALANCEO"
      CLS : PRINT HEATAIR; FLAMERAD; QFLUE; QBALANCE; QBALANCEO
      PRINT "LB;RB;TRADFL;BOUNDFND": PRINT LB; RB; TRADFL; BOUNDFND
      PRINT "MRING": FOR XXX% = 1 TO NT%: RR% = ORN%(XXX%): PRINT MRING(XXX%, RR%): NEXT XXX%
      PRINT "ARING": FOR XXX% = 1 TO NT%: RR% = ORN%(XXX%): PRINT ARING(XXX%, RR%): NEXT XXX%
      FOR SURFACE% = 1 TO 6: PRINT QRADS(SURFACE%): NEXT SURFACE%
31216 ' USE THE BISECTION METHOD TO SOLVE FOR STEADY STATE FLAME TEMEPRATURE
      '
      IF ABS(QBALANCE) < 1 THEN GOTO 31290
      IF GUESS1 = 0 THEN QBALANCEO = QBALANCE: GUESS1 = 1
      IF BOUNDFND = 1 THEN GOTO 31230
      '
      ' FIND THE LEFT AND RIGHT BOUNDS ON EITHER SIDE OF THE SOLUTION
      '
      IF QBALANCE * QBALANCEO > 0 AND QBALANCE > 0 THEN LB = TRADFL: TRADFL = TRADFL * 2: RB = TRADFL: GOTO 31260
      IF QBALANCE * QBALANCEO > 0 AND QBALANCE < 0 THEN RB = TRADFL: TRADFL = TRADFL / 2: LB = TRADFL: GOTO 31260
      BOUNDFND = 1
      '
31230 ' IF THE BOUNDS ARE FOUND KEEP BISECTING UNTIL ROOT IS FOUND
      '
      IF QBALANCE * QBALANCEO > 0 AND QBALANCE > 0 THEN LB = TRADFL: TRADFL = (LB + RB) / 2: GOTO 31260
      IF QBALANCE * QBALANCEO > 0 AND QBALANCE < 0 THEN RB = TRADFL: TRADFL = (LB + RB) / 2: GOTO 31260
      IF QBALANCEO > 0 THEN RB = TRADFL: TRADFL = (LB + RB) / 2: GOTO 31260
      IF QBALANCEO < 0 THEN LB = TRADFL: TRADFL = (LB + RB) / 2: GOTO 31260
31260 QBALANCEO = QBALANCE: GOTO 31181
      TFLAME2 = TRADFL
31290 '
      '
      'QFLUET=QFLUET+QFLUE:' SUM THE ENERGY TRANSFERRED TO THE FLUE FOR THE TIMESTEP
      '
      ' SUM THE RADIATION FROM THE WOODPILE THAT FALLS ON EACH SURFACE FOR THAT TIME STEP
      '
      FOR SURFACE% = 1 TO 6: FLWDRAD(SURFACE%) = 0: FOR I% = 1 TO NT%: FLWDRAD(SURFACE%) = FLWDRAD(SURFACE%) + QRADW(I%, SURFACE%) + QRADFL(SURFACE%): QRADW(I%, SURFACE%) = 0: QRADFL(SURFACE%) = 0: NEXT I%: NEXT SURFACE%
      '
      'SUM NET RE-RADIATION FROM SURFACE TO ALL OTHER SURFACES
      '
      FOR SURFACE% = 1 TO 6
      QRADS(SURFACE%) = 0
      FOR SURFACEI% = 1 TO 6
      QRADS(SURFACE%) = QRADS(SURFACE%) + TSTEP * EMISS(SURFACE%) * EMISS(SURFACEI%) * SBCONST * ((((TWALL(SURFACE%, 1) + 273.15) ^ 4) - (TWALL(SURFACEI%, 1) + 273.15) ^ 4)) * ARWALL(SURFACE%) * F(SURFACE%, SURFACEI%): _
                                                      'IF NO GLASS DOOR SURFACE 5 DOES NOT RADIATE TO FIREBOX
      IF SURFACE% = 5 AND GLASSDR$ = "N" THEN QRADS(SURFACE%) = QRADS(SURFACE%) - TSTEP * EMISS(SURFACE%) * EMISS(SURFACEI%) * SBCONST * ((((TWALL(SURFACEI%, 1) + 273.15) ^ 4) - (TWALL(5, 11) + 273.15) ^ 4)) * ARWALL(SURFACEI%) * F(SURFACEI%,  _
SURFACE%)
      IF GLASSDR$ = "Y" AND SURFACE% = 5 THEN QSTO5 = QSTO5 + TSTEP * TRANSMISS(5) * SBCONST * ((EMISS(SURFACEI%) * ((TWALL(SURFACEI%, 1) + 273.15) ^ 4)) - (TWALL(5, 11) + 273.15) ^ 4) * ARWALL(SURFACEI%) * F(SURFACEI%, SURFACE%): _
                                                      'TRANSMISSION EQUATION
      NEXT SURFACEI%
      TOTQRAD(SURFACE%) = FLWDRAD(SURFACE%) - QRADS(SURFACE%)
      NEXT SURFACE%
      ' CHECK TO SEE IF THE INSIDE SURFACE IS OPEN, HAS GLASS DOORS, OR HAS A LINER-USE APPROPRIATE ALGORITHMS
      FOR SURFACE% = 1 TO 6
      QCONV(SURFACE%) = 0: QCONVOUT(SURFACE%) = 0: QCONDOUT(SURFACE%) = 0
      QIN = TOTQRAD(SURFACE%)
      FOR SECTION% = 1 TO 10
      HCONVI = 8.33: QCONVL = 0: QCONVEXT = 0: QOUTRAD = 0: QINRAD = 0
      IF SURFACE% = 5 THEN CALL room.surface: GOTO 31445
      QOUT = TSTEP * (ARWALL(SURFACE%) * 2 / (RSI(SURFACE%, SECTION%) + RSI(SURFACE%, SECTION% + 1))) * ((TWALL(SURFACE%, SECTION%)) - (TWALL(SURFACE%, SECTION% + 1))): 'QCOND IS THE CONDUCTIVE HEAT LOSS TO NEXT ELEMENT IN WALL
      IF SECTION% = 1 THEN QCONVL = TSTEP * HCONVI * ARWALL(SURFACE%) * (TWALL(SURFACE%, 1) - ((2 * TINTAKE + TN(6)) / 3)): QCONV(SURFACE%) = QCONVL
      IF SECTION% = 1 AND SURFACE% = 6 THEN QCONVL = TSTEP * HCONVI * ARWALL(SURFACE%) * (TWALL(SURFACE%, 1) - TSTACK): QCONV(SURFACE%) = QCONVL: GOTO 31440
      IF FTYPE$ = "W" AND SECTION% = 4 THEN CALL qoutrad1: QTEMPRAD = QOUTRAD
      IF FTYPE$ = "W" AND SECTION% = 6 THEN QINRAD = QTEMPRAD
      IF FTYPE$ = "F" AND SECTION% = 3 THEN CALL qoutrad1: QTEMPRAD = QOUTRAD: ' QOUTRAD IS ASSIGNED FOR FACTORY BUILT FIREPLACES
      IF FTYPE$ = "F" AND SECTION% = 5 THEN QINRAD = QTEMPRAD
      IF SECTION% > 1 AND SECTION% < 10 THEN GOTO 31440
      IF SECTION% = 10 THEN QOUT = 0: QOUTRAD = TSTEP * EMISS(SURFACE%) * SBCONST * ARWALL(SURFACE%) * (((TWALL(SURFACE%, 10) + 273.15) ^ 4) - ((TWALL(SURFACE%, 11) + 273.15) ^ 4)): QCONDOUT(SURFACE%) = QOUTRAD
      IF SECTION% = 10 THEN QCONVEXT = TSTEP * (HCONV) * ARWALL(SURFACE%) * (TWALL(SURFACE%, 10) - TWALL(SURFACE%, 11)): QCONVOUT(SURFACE%) = QCONVEXT
31440 QWRISE(SURFACE%, SECTION%) = QIN + QINRAD - QOUT - QOUTRAD - QCONVL - QCONVEXT
31445 TRISE = QWRISE(SURFACE%, SECTION%) / (MASSWALL(SURFACE%, SECTION%) * CPWALL(SURFACE%, SECTION%))
      TWALL(SURFACE%, SECTION%) = TWALL(SURFACE%, SECTION%) + TRISE
      QIN = QOUT
      NEXT SECTION%
      NEXT SURFACE%
      'QOUT = TRANSMISS(SURFACE%)*((WDRAD(SURFACE%)-(TSTEP*SBCONST*EMISS(SURFACE%)*((TAIR+273.15)^4)))):'IF SURFACE% IS GLASS QCOND(SURFACE%) IS RADIATION
      '
      ' CUMULATIVE ENERGY DISTRIBUTION THROUGHOUT WOOD PILE AND SURROUNDINGS
      '
31600 SOURCEQ = SOURCEQ + HEATAIR
      TQFLUE = TQFLUE + QFLUE
      TOTFLRAD = TOTFLRAD + FLAMERAD
      FOR I% = 1 TO NT%: TWDRAD = TWDRAD + WOODRAD(I%): NEXT I%
      FOR SURFACE% = 1 TO 6
      CUMWDRAD(SURFACE%) = CUMWDRAD(SURFACE%) + FLWDRAD(SURFACE%)
      SURFRAD(SURFACE%) = SURFRAD(SURFACE%) - QRADS(SURFACE%)
      TOTRAD(SURFACE%) = SURFRAD(SURFACE%) + CUMWDRAD(SURFACE%)
      TOTCONV(SURFACE%) = TOTCONV(SURFACE%) + QCONV(SURFACE%)
      NETRAD(SURFACE%) = TOTRAD(SURFACE%) - TOTCONV(SURFACE%)
      FOR SECTION% = 1 TO 10
      TOTSTOR(SURFACE%, SECTION%) = TOTSTOR(SURFACE%, SECTION%) + QWRISE(SURFACE%, SECTION%)
      NEXT SECTION%
      TOTCONDOUT(SURFACE%) = TOTCONDOUT(SURFACE%) + QCONDOUT(SURFACE%)
      EXTCONV(SURFACE%) = EXTCONV(SURFACE%) + QCONVOUT(SURFACE%)
      NEXT SURFACE%
31609 REM
        'LPRINT "LEAVING energy.balance"
END SUB

STATIC SUB film.coeff ()
'==========================================================================
'
'       FLUE FILM HEAT TRANSFER COEFFICIENT & FRICTION FACTORS (12500)
'                 AS A FUNCTION OF REYNOLDS NUMBER
'
'==========================================================================
       'LPRINT "ENTERING film.coeff"
       REM
      IF Y% < (NFPSEGS% + 1) THEN V = (DHF(Y%)) / (M(1, Y%) / ABS(MF(5)))
      IF Y% >= (NFPSEGS% + 1) THEN V = (HF / (NE% - NFPSEGS%)) / (M(1, Y%) / ABS(MF(5)))
      RE = (353.6 / (TI(1, Y%) + TA)) * V * DIA(1, Y%) / MU
      U(1, Y%) = 1.8 * (.0238 / DIA(1, Y%)) * (.021 * (.78 ^ .5) * RE ^ .8)
      FF(Y%) = DHF(Y%) * ((38700! / RE) ^ 1.24) / 10
      IF (TI(1, Y%) - TI(2, Y%)) < 10 THEN FF(Y%) = K1 * DHF(Y%)
      IF FF(Y%) < (K1 * DHF(Y%)) THEN FF(Y%) = (K1 * DHF(Y%))
      IF U(1, Y%) < UI THEN U(1, Y%) = UI
      KE(4) = KE(4) + FF(Y%)' IF Y% < (NFPSEGS%+1) THEN KE(4)=KE(4)+FF(Y%)  ELSE KE(3)=KE(3)+FF(Y%)
      UF = UF + U(1, Y%)
      DIA(1, Y%) = (DI2(1, Y%) / PIE) * (1 - .096): IF Y% < (NFPSEGS% + 1) THEN A(1, Y%) = (PIE * DIA(1, Y%)) * DHF(Y%) ELSE A(1, Y%) = (PIE * DIA(1, Y%)) * HF / 8
        'LPRINT "LEAVING film.coeff"
END SUB

STATIC SUB flue.heattransfer ()
'==========================================================================
'
'                TRANSIENT HEAT TRANSFER MODEL OF THE FLUE (9000)
'  PARAMETERIZED TEMPERATURE ALGORITHMS ARE CALLED IN SUBROUTINE 12000
'
'==========================================================================
      'LPRINT "ENTERING flue.heattransfer"
      REM
     ' KK = 0
     KE(4) = (NELBOWS% * .5)
     UF = 0
      REM
      REM
      FOR Y% = 1 TO NE%
      REM :----MASS OF THE FLUE GAS ELEMENT = VOLUME OF ELEMENT  X  DENSITY AT INITIAL TEMPERATURE-----
     IF Y% < (NFPSEGS% + 1) THEN M(1, Y%) = ((ARD(5) * DHF(Y%)) * (353.6 / (TI(1, Y%) + TA)))
     IF Y% > NFPSEGS% THEN M(1, Y%) = ((ARD(5) * (HF / (NE% - NFPSEGS%))) * (353.6 / (TI(1, Y%) + TA)))
      REM
      REM :--SUBROUTINE 12500 CALCULATES THE HEAT TRANSFER COEFFICIENTS NEEDED FOR THE FOLLOWING WORK & FRICTION FACTORS FOR THE PRESSURE LOSS ROUTINE--------
      REM
      CALL film.coeff ' (12500)
      IF Y% = 1 THEN TB = TN(5)
      IF Y% = 1 THEN GOTO 9220
     TB = TI(1, (Y% - 1))
9220  IF MF(5) > 0 THEN GOTO 9250
      IF Y% = NE% THEN TB = TN(1): GOTO 9250
     TB = TI(1, (Y% + 1))
9250 INDT = 1
     ITW = M(1, Y%) / ABS(MF(5))
     OTW = (M(1, Y%) * HC(1, Y%) / (U(1, Y%) * A(1, Y%)))
     D1TM = TB - TI(1, Y%)
     D2TM = TI(1, Y%) - TI(2, Y%)
     CALL temp.update   '(12020)
     TF(1, Y%) = TI(1, Y%) + DTM
      FOR J% = 2 TO 4
     INDT = 2
     ITW = (M(J%, Y%) * HC(J%, Y%) / (U(J% - 1, Y%) * A(J% - 1, Y%)))
     OTW = (M(J%, Y%) * HC(J%, Y%) / (U(J%, Y%) * A(J%, Y%)))
     D1TM = TI(J% - 1, Y%) - TI(J%, Y%)
     D2TM = TI(J%, Y%) - TI(J% + 1, Y%)
     CALL temp.update   ' (12020)
     TF(J%, Y%) = TI(J%, Y%) + DTM
     IF FPI$ = "U" THEN GOTO 9400 ELSE GOTO 9410
9400  IF Y% < (NFPSEGS% + 1) AND J% > 2 THEN TF(J%, Y%) = TN(9)
9410 NEXT J%
      NEXT Y%
      FOR Y% = 1 TO NE%
      FOR J% = 1 TO 4
     TI(J%, Y%) = TF(J%, Y%)
      NEXT J%
      NEXT Y%
     'KE(4) = KK / NE%
     UF = UF / NE%
      REM
9510  REM :----CALCULATE NEW COLUMN WEIGHT OF THE FLUE GAS BASED ON THE NEW FLUE TEMPERATURES------
      REM
     GF = 0!
      FOR Y% = 1 TO NE%
     RW = 353.6 / (TI(1, Y%) + TA)
     GF = GF + (RW * GC * EH(Y%))
      NEXT Y%
      REM
      REM
     TN(4) = TI(1, 1)
      IF MF(5) < 0 THEN TN(5) = TN(4)
     TN(3) = TI(1, NE%)
     TN(2) = TN(3)
      REM
      REM :--------NEW DENSITIES----------
      REM
      FOR X% = 1 TO 19
     RO(X%) = 353.6 / (TN(X%) + TA)
      NEXT X%
     REM:----------- NEW FLOW AREAS ACCOUNTING FOR DISPLACEMENT THICKNESS ------
     ARD(2) = PIE * (DIA(1, NE%) ^ 2) / 4: ARD(3) = ARD(2): ARD(4) = PIE * (DIA(1, 1) ^ 2) / 4: ARD(5) = ARD(4)
        'LPRINT "LEAVING flue.heattransfer"
END SUB

STATIC SUB friction.factors ()

REM====================================================================
REM:
REM:          FRICTION FACTORS AND ELA's OF THE SYSTEM (4000)
REM:
REM====================================================================
      REM: ---------K FACTOR NORMAL FLOW VALUES------------
      REM:
      'LPRINT "ENTERING friction.factors"
      FOR X% = 1 TO 19
      READ KE(X%)
      NEXT X%
     KE(4) = (NELBOWS% * .5)  'IF KE(4)< K1  THEN KE(4)= K1
     KE(2) = FCAPL
      REM
     ADR = AR(11) * APRD / 100
'--------------------------------------------------------------------------
      REM :  E Q U I V A L E N T   L E A K A G E    A R E A S
      REM :
      REM :   1 - CHIMNEY ELA
      REM :   2 - DILUTION PORT ELA (DESIGN FLOWS)
      REM :   3 - DILUTION PORT ELA (REVERSE FLOW)
      REM :   4 - FIREBOX INLET ELA
      REM :   5 - FIREBOX OUTLET ELA
      REM
'--------------------------------------------------------------------------
     ELA(1) = ARD(4) * ((2.68 / (KE(4) + KE(5) + KE(2))) ^ .5)
     ELA(2) = (AR(11) * ((2.68 / KE(11)) ^ .5))
     ELA(3) = (ADR * ((2.68 / KE(11)) ^ .5))
     IF INTAKE$ = "Y" THEN KE15 = KE(15) + NELINTAK * .45 ELSE KE15 = KE(15)
     ELA(4) = AR(15) * ((2.68 / KE15) ^ .5)
     ELA(5) = AR(18) * ((2.68 / KE(18)) ^ .5)
     IF GLASSDR$ = "Y" THEN ELA4GD = ELA(4): ELA2GD = ELA(2)
        'LPRINT "LEAVING friction.factors"
END SUB

STATIC SUB Ini.Character ()

      '==========================================================================
      '     INITIATION OF WOOD BURNING CHARACTERISTICS (25000)
      '==========================================================================
      'LPRINT "ENTERING ini.character"
      CRAD = 5.672E-08
      '     PROPERTIES OF HARDWOODS & SOFTWOODS (KINDLING)
      RHARD = 6
      RSOFT = 7
      BRATE = .0003: '.000225
      REM:  TBRLIMIT=0.003
      '--------------------------------------------------------------------------
      '   PROPERTIES OF MATERIALS SURROUNDING THE FIRE, & EXPOSURE TO FIRE AS FRACTION
      '   #1  - INDOOR ROOM CHARACTERISTICS
      '   #2  - BACK WALL
      '   #3  - SIDE WALLS
      '   #4  - FLOOR (ASHES OR BARE LIKE BACK WALL)
      '--------------------------------------------------------------------------
      MS(1) = 500: CPS(1) = 1000: EXPOSR(1) = .35
      MS(2) = MOHE * .3: CPS(2) = HCHE: EXPOSR(2) = .3
      MS(3) = MOHE * .7: CPS(3) = HCHE: EXPOSR(3) = .3
      MS(4) = 25: CPS(4) = 1600: EXPOSR(4) = .05
      '--------------------------------------------------------------------------
      '    KEY CONDITIONS RELATING TO AIR FLOW IN THE FIREBOX AREA
      '--------------------------------------------------------------------------
      STOICHAIR = 13.8

      ' ASSUME THAT ONLY 30% OF AIR FLOW INTO FIREBOX IS AVAILABLE FOR COMBUSTION

      FRACOMB = .25: REM SEE LINE 27198

      '     PORTION OF RELEASED COMBUSTION ENERGY TO ITSELF, AIR, ADJACENT WOOD
      UNBURND = 5
      PWR = .2
      PAW = .08
      '
      '   ELEMENT VOLUMES, SURFACE AREAS, MASSES, HEAT CAPACITIES, TIME CONSTANTS, COMBUSTION ENERGY
      '   NOTE:   HARD WOOD PIECES ARE ONE SIXTH OF A LOG

      TMASS = 0: FOR I% = 1 TO NT%: TOPRING%(I%) = NWE%: OMRING(I%) = 0: NEXT I%
      FOR I% = 1 TO NT%
      FOR J% = 1 TO NWE%
      J1% = J% - 1
      IF I% > NPS% THEN GOTO 25700

      '  SOFTWOOD  MASS, CONDUCTANCE & SENSIBLE HEAT CAPACITY

      RRING(I%, J%) = RRING(I%, J1%) + DRAD(I%)
      ARING(I%, J%) = LENGTH * 2 * PIE * RRING(I%, J%) / NPL(I%)
      IF NPL(I%) > 1 THEN ARING(I%, J%) = ARING(I%, J%) + 2 * RRING(I%, J%) * LENGTH
      VOLRING(I%, J%) = LENGTH * PIE * (RRING(I%, J%) ^ 2 - RRING(I%, J1%) ^ 2) / NPL(I%)
      MRING(I%, J%) = VOLRING(I%, J%) * ROWSOFT: IF J% = NWE% THEN MRING(I%, J%) = MRING(I%, J%) + MRINGO(I%) ELSE MRING(I%, J%) = MRING(I%, J%) + (MRINGL(I%) - MRINGO(I%)) / 4
      OMRING(I%) = OMRING(I%) + MRING(I%, J%)
      TMASS = TMASS + MRING(I%, J%)
      URING(I%, J%) = 1 / (DRAD(I%) * RSOFT + .000001)
      HCRING(I%, J%) = HCSOFT
      GOTO 25800
25700 '  HARDWOOD MASS, CONDUCTANCE & SENSIBLE HEAT CAPACITY
      RRING(I%, J%) = RRING(I%, J1%) + DRAD(I%)
      ARING(I%, J%) = (LENGTH * 2 * PIE * RRING(I%, J%) / NPL(I%))
      IF NPL(I%) > 1 THEN ARING(I%, J%) = ARING(I%, J%) + (2 * RRING(I%, J%) * LENGTH)
      VOLRING(I%, J%) = LENGTH * PIE * (RRING(I%, J%) ^ 2 - RRING(I%, J1%) ^ 2) / NPL(I%)
      MRING(I%, J%) = VOLRING(I%, J%) * ROWHARD: IF J% = NWE% THEN MRING(I%, J%) = MRING(I%, J%) + MRINGO(I%) ELSE MRING(I%, J%) = MRING(I%, J%) + (MRINGL(I%) - MRINGO(I%)) / 4
      OMRING(I%) = OMRING(I%) + MRING(I%, J%)
      MMRING(I%, J%) = MRING(I%, J%) * .1
      TMASS = TMASS + MRING(I%, J%)
      URING(I%, J%) = 1 / (DRAD(I%) * RHARD)
      HCRING(I%, J%) = HCHARD
25800 NEXT J%
      DRYMAS(I%) = OMRING(I%) * (100 - MCONTENT(I%)) / 100
      NEXT I%
      '
      ' INITIALIZATION OF TEMPERATURES
      '
      FOR I% = 1 TO NT%
      IF F$ = "ON" AND BRAND$ = "Y" THEN TORN(I%) = TRING(I%, ORN%(I%))
      FOR J% = 1 TO NWE%
      IF F$ = "ON" AND BRAND$ = "Y" AND J% = NWE% THEN TRING(I%, NWE%) = 20 + ((MRINGO(I%) * CPLOG(I%, ORN%(I%)) * (TORN(I%) - 20)) / ((MRINGO(I%) * CPLOG(I%, ORN%(I%))) + ((MRING(I%, NWE%) - MRINGO(I%)) * HCRING(I%, NWE%)))): GOTO 26320
      TRING(I%, J%) = 20
26320 NEXT J%
      NEXT I%
      IF F$ = "ON" AND BRAND$ = "N" THEN TRING(2, NWE%) = 300: TRING(1, NWE%) = 300: TRING(3, NWE%) = 300
      IF F$ = "ON" AND TRING(2, NWE%) < 204 THEN TRING(2, NWE%) = 300
      FOR II% = 1 TO 4
        TS(II%) = T9
      NEXT
      IF FL1% = 1 THEN GOTO 26490
      '     SETTING UP BEFORE THE TIME STEP
      KEY OFF
      '
26490 REM
        'LPRINT "LEAVING ini.character"
END SUB

STATIC SUB IniConditions ()
'==========================================================================
'               INITIALIZE FLUE TEMPERATURES
'==========================================================================
      'LPRINT "ENTERING iniconditions"
      REM
     GF = 0!
      FOR Y% = 1 TO NE%
     RW = 353.6 / (TI(1, Y%) + TA)
     GF = GF + (RW * GC * EH(Y%))
      NEXT Y%
      REM
      REM
     TN(4) = TI(1, 1)
      IF MF(5) < 0 THEN TN(5) = TN(4)
     TN(3) = TI(1, NE%)
     TN(2) = TN(3)
      REM
      REM :--------NEW DENSITIES----------
      REM
      FOR X% = 1 TO 19
     RO(X%) = 353.6 / (TN(X%) + TA)
      NEXT X%
     REM:----------- NEW FLOW AREAS ACCOUNTING FOR DISPLACEMENT THICKNESS ------
     ARD(2) = PIE * (DIA(1, NE%) ^ 2) / 4: ARD(3) = ARD(2): ARD(4) = PIE * (DIA(1, 1) ^ 2) / 4: ARD(5) = ARD(4)
        'LPRINT "LEAVING iniconditions"
END SUB

STATIC SUB IniTempProfile ()

'==========================================================================
'
'    INITIAL TEMPERATURE PROFILES FOR FLUE AND GAS FLOW NETWORK (4500)
'
'==========================================================================
'
'   READ IN FLUE LINER INITIAL TEMPERATURES
'
'   CHIMNEY STRUCTURE & SURROUNDINGS TEMPERATURES
'
     'LPRINT "ENTERING initempprofile"
     FOR X% = 1 TO NE%
     TI(5, X%) = T1: IF X% < (NFPSEGS% + 1) THEN TI(5, X%) = T9: GOTO 4662
     IF ELHT(X%) > (XPT + HF / (2 * (NE% - NFPSEGS%))) AND X% < NE% THEN TI(5, X%) = T9
4662 IF SCSFLAG% = 1 THEN GOTO 4680
     IF ELHT(X%) < (XPT + HF / (2 * (NE% - NFPSEGS%))) OR X% = NE% THEN GOTO 4680
     TI(4, X%) = TI(5, X%): IF TI(3, X%) < TI(4, X%) THEN TI(3, X%) = TI(4, X%): TI(2, X%) = TI(3, X%)
4680  NEXT X%
      FOR X% = 1 TO NE%
     IF X% < (NFPSEGS% + 1) THEN EH(X%) = RISE(X%): GOTO 4720: REM IF X<3 THEN EH(X)=RISE/2
      EH(X%) = (HF / (NE% - NFPSEGS%))
4720  NEXT X%
      REM :
      REM : --------COMPUTE DENSITY TERMS FOR GAS FLOW NETWORK POINTS(19)------
      REM
      FOR X% = 1 TO 19
     RO(X%) = 353.6 / (TN(X%) + TA)
     NEXT
        'LPRINT "LEAVING initempprofile"
END SUB

STATIC SUB Light.Analysis ()

'==========================================================================
'
'                 P A R A M E T E R    A N A L Y S I S
'                 AT LIGHTING OF THE WOOD PILE (11000)
'
'==========================================================================
      'LPRINT "ENTERING light.analysis"
      IF FL1% = 1 THEN 11550 ELSE 11070
11070 PRINT #2, : PRINT #2,
      PRINT #2, "S Y S T E M    P A R A M E T E R S"
      PRINT #2, "==================================": PRINT #2,
       REM
      PAR(1) = INT(100 * (((QF + FP) / (1000 * CC)) ^ (1 / N)) + .5) / 100
      SN = 1: IF VV < 0 THEN SN = 0 - 1
      PAR(2) = 0 + INT(100 * (((PHC + CPWENV(LEAKDIST)) * .5 * RO(1) * (VH ^ 2)) - (SN * PVC * .5 * RO(1) * (ABS(VV) ^ 2))) + .5) / 100
      PAR(3) = PAR(2) - PAR(1)
      PAR(4) = INT(100 * (353.6 * GC * (((HF - ABS(VCL)) / (TN(9) + TA)) + (ABS(VCL) / (TN(1) + TA)) - (HF / (TT + TA)))) + .5) / 100
      PAR(5) = INT(100 * (PAR(4) + PAR(3)) + .5) / 100
      L1A = AR(15) * (2.68 / KE(15)) ^ .5
      L2A = AR(18) * (2.68 / KE(18)) ^ .5
      IF L1A < .01 THEN L1A = 1000000!
      PAR(6) = INT(1000 * (1 / ((1 / L1A) + (1 / L2A))) + .5) / 1000
      L1A = ARD(4) * (2.68 / (KE(4) + KE(2) + KE(5))) ^ .5
      PAR(7) = INT(1000 * L1A + .5) / 1000
      L1A = ADR * (2.68 / KE(11)) ^ .5
      PAR(8) = INT(1000 * L1A + .5) / 1000
      L1A = 1.157 * (RO(1) ^ .5) * CC * ((10) ^ (N - .5))
      PAR(9) = INT(1000 * L1A + .5) / 1000
      PAR(10) = INT(10 * (M(2, NFPSEGS% + 1) * HC(2, NFPSEGS% + 1) / (U(1, NFPSEGS% + 1) * A(1, NFPSEGS% + 1))) + .5) / 10
      HD$(1) = "ENVELOPE ADVERSE PRESS.(FANS & FIREPLACE)  (PA):"
      HD$(2) = "WIND INDUCED DRIVING PRESSURE              (PA):"
      HD$(3) = "NET BOUNDARY DRIVING PRESSURE              (PA):"
      HD$(4) = "CHIMNEY/HOUSE BUOYANCY PRESSURE AT STANDBY (PA):"
      HD$(5) = "NET DRIVING PRESSURE PARAMETER (AT STANDBY)(PA):"
      HD$(6) = "FIREBOX EQUIVALENT LEAKAGE AREA OF FLOW    (m2):"
      HD$(7) = "CHIMNEY EQUIVALENT LEAKAGE AREA OF FLOW    (m2):"
      HD$(8) = "E.L.A.  OF CHIMNEY CONNECTION              (m2):"
      IF FB$ = "F" THEN HD$(8) = "E.L.A.  OF UPPER OPENING OR OF DOORS       (m2):"
      HD$(9) = "ENVELOPE EQUIVALENT LEAKAGE AREA AT 10 PA  (m2):"
      HD$(10) = "CHIMNEY LINER HEAT TRANSFER TIME CONSTANT   (S):"
      FOR X% = 1 TO 10
      IF X% = 6 THEN PRINT #2,
      PRINT #2, HD$(X%); "  "; PAR(X%)
      NEXT X%
      PRINT #2, : PRINT #2,
      PRINT #2, "FLUE LOCATION:  "; : IF CHIMT$ = "I" THEN PRINT #2, "INTERIOR" ELSE PRINT #2, "EXTERIOR"
      PRINT #2, "CHIMNEY FLOW DIRECTION AT STANDBY: ";
       IF VL(4) < 0 THEN PRINT #2, "REVERSED  ("; INT(100 * VL(4) + .5) / 100; " M/S)": GOTO 11530
      PRINT #2, " UPWARD   ("; INT(100 * VL(4) + .5) / 100; " M/S)"
11530 PRINT #2,
       CALL LineSummary(1) ' (18570)
11550  REM
        'LPRINT "LEAVING light.analysis"
END SUB

STATIC SUB Light.Wood ()
'==========================================================================
'
'                LIGHTING THE WOOD PILE (19500)
'
'==========================================================================
       REM
      'LPRINT "ENTERING light.wood"
      PRINT #2, : PRINT #2, "******* THE WOOD PILE WILL BE LIT AT "; (INT(100 * SCS + .5) / 100); " SECONDS *******"
      IF FL1% = 1 THEN 19600 ELSE CALL Light.Analysis
19600  REM
      'LPRINT "LEAVING light.wood"
END SUB

STATIC SUB LineSummary (flag%)
REM===================================================================
REM
REM :      HEADINGS FOR LINE SUMMARY (18500)
REM
REM===================================================================
       REM
      'LPRINT "ENTERING linesummary"
      IF flag% = 0 THEN
        PRINT #2, CHR$(15)
      END IF
      PRINT #2, : PRINT #2, : PRINT #2, : PRINT #2, : PRINT #2, "C A S E:  ";
      PRINT #2, "  WOOD BURNING - ";
      PRINT #2, TITLE$; : PRINT #2, "                   DATE: "; DATE$
      PRINT #2, "=========================================================================== ": PRINT #2, : PRINT #2,
      IF P$ = "P" THEN GOTO 18670
      PRINT #2, "        TIME      BURN RATE    WEIGHT OF   FIREBOX     DILUTION    CHIMNEY     INC. ENVEL  ENVELOPE    FIREBOX     FIREBOX     MIXING      MEAN FLUE   GAS EXIT    MEAN FLUE   INSTANT.    FLUE FILM     FLUE FRICTION"
      PRINT #2, "        (SECS)      (kW)       WOOD (kg)   FLOW(L/S)   FLOW(L/S)   FLOW(L/S)   FLOW(L/S)   PRES DROP   WALL TEMP   EXIT TEMP   TEMP(C)     GAS TEMP    TEMP (C)    LINER TEMP  EFFICIENCY  HT TRANS CF   FACTOR"
      PRINT #2, " "
      GOTO 18680
18670 PRINT #2, "             TIME       NET BUOYANCY    WIND EFFECT   ENVELOPE LOSS  FRICTION LOSS   NET DRIVING   FIREBOX BUOY.   INLET DROP   OUTLET DROP    NET FIREBOX      DILUTION "
      REM
18680 PRINT #4, CHR$(15)
      PRINT #4, : PRINT #4, : PRINT #4, : PRINT #4, : PRINT #4, "C A S E:  ";
      PRINT #4, "  WOOD BURNING - ";
      PRINT #4, TITLE$; : PRINT #4, "                   DATE: "; DATE$
      PRINT #4, "=========================================================================== ": PRINT #2, : PRINT #2,
      PRINT #4, "        TIME      BURN RATE               WALL    TEMPERATURES                     MID   WALL              BACK  WALL        RAD HEAT TO     FLAME       HEAT-AIR       FLUE     FLAME RAD.  WOOD RAD.     MOISTURE CONTENT"
      PRINT #4, "         (s)      (kW)          FRONT       BACK        SIDE        FLOOR         BACK     SIDE          BACK      SIDE     HOUSE (Whr)     TEMP (C)    TRANSFER    ENERGY(Wh)     (Wh)       (Wh)     REMAIN WOOD     PYROL GAS"
      PRINT #4, " "
        'LPRINT "LEAVING linesummary"
END SUB

STATIC SUB mass.flow ()
'==========================================================================
'
'                    MASS FLOW  SUBROUTINE (5000)
'
'==========================================================================
      REM
      REM :-----------CALCULATION OF MASS PARAMETERS---------------
      REM
     'LPRINT "ENTERING mass.flow"
     IF ITER > 99 THEN Q6 = Q6LAST: Q9 = Q9LAST
     MF(6) = Q6  ': MTFUEL = 0
     MF(19) = Q9 + MTFUEL
      FOR X% = 1 TO 5
     MF(X%) = MF(6)
      NEXT
      REM
      FOR X% = 10 TO 12
     MF(X%) = MF(6) - MF(19)
      NEXT
      REM
      FOR X% = 13 TO 14
     IF INTAKE$ = "Y" AND SCS > CDT THEN MF(X%) = 0: GOTO 5200
     MF(X%) = MF(19) - TMASCOMB
5200 NEXT
     MF(15) = MF(19) - TMASCOMB
      REM
      FOR X% = 16 TO 18
     MF(X%) = MF(19)
      NEXT
      REM
      IF SCS > EXFAN.ON AND SCS < EXFAN.OFF THEN MCOMPFAN = MCOMP ELSE MCOMPFAN = 0
      FOR X% = 7 TO 9
        MF(X%) = MF(10) + MF(13) + MCOMPFAN
      NEXT
      REM
      FOR X% = 1 TO 19
        VF(X%) = MF(X%) / RO(X%)
      NEXT
      REM
      REM
      REM:------VELOCITIES--------
      REM
      FOR X% = 1 TO 19
        IF AR(X%) < .0004 THEN VL(X%) = 0: GOTO 5410
        VL(X%) = VF(X%) / AR(X%)
        IF X% > 1 AND X% < 6 THEN VL(X%) = VF(X%) / ARD(X%)
5410 NEXT X%
     IF VF(11) < 0 THEN VL(11) = VF(11) / ADR
     'LPRINT "LEAVING mass.flow"
END SUB

STATIC SUB Network.points ()
'==========================================================================
'
'    GUIDE TO IDENTIFY NETWORK POINTS (16000, 16020)
'
'==========================================================================
       REM
      'LPRINT "ENTERING network.points"
      PRINT #2, TAB(31);
      PRINT #2, "<-----------------C H I M N E Y----------------->";
      PRINT #2, " <--------E N V E L O P E------>";
      PRINT #2, "<--DILUTION OPENING->";
      PRINT #2, " <---------------------F I R E B O X----------------------->"
        'LPRINT "LEAVING network.points"
END SUB

STATIC SUB pressure.par ()
'==========================================================================
'             CALCULATION OF PRESSURE PARAMETERS (6000)
'==========================================================================
      REM
      REM :----LOOP #1:   FLUE PIPE - VENT OR CHIMNEY - CAP - OUTDOORS - ENVELOPE - INDOORS DOWN TO DILUTION DEVICE------
      REM
      'LPRINT "ENTERING pressure.par"
     ELA(1) = ARD(2) * ((2.68 / (KE(4) + KE(5) + KE(2))) ^ .5)
     TT = ((353.6 * GC * (HF + RISET)) / GF) - TA
     TFLUE = TT
     PB(1) = (353.6 * GC * (((HF + RISET + ABS(HT(6) - HT(5)) - ABS(VCL)) / (TN(9) + TA)) + (ABS(VCL) / (TN(1) + TA)) - ((HF + RISET) / (TT + TA)) - (ABS(HT(6) - HT(5)) / (TN(6) + TA))))
     SN = 1: IF VV < 0 THEN SN = 0 - 1
     PB(2) = (((PHC + CPWENV(LEAKDIST)) * .5 * RO(1) * (VH ^ 2)) + (SN * PVC * .5 * RO(1) * (ABS(VV) ^ 2)))
     SN = 1: IF MF(8) < 0 THEN SN = 0 - 1
     PB(3) = 0 - SN * (((ABS(MF(8)) / RO(8)) / CC) ^ (1 / N))
     VAC = ((VF(4) * KE(4)) + (VF(5) * KE(5)) + (VF(2) * KE(2))) / (KE(4) + KE(5) + KE(2))
     SN = 1: IF VAC < 0 THEN SN = 0 - 1
     PB(4) = 0 - SN * ((473.8 / (TT + TA)) * ((ABS(VAC) / ELA(1)) ^ 2))
     PB(5) = PB(1) + PB(2) + PB(3) + PB(4)
      REM
      REM :---LOOP #2:  OUTSIDE FIREBOX -FIREBOX INLET - UP THROUGH FIREBOX - OUT TO MIXING AREA IN DILUTION DEVICE-------
      REM
     TEF = (1 / ((FRACOMB / (TN(16) + TA)) + ((1 - FRACOMB) / (TN(17) + TA)))) - TA
     COLWT = HH / (TN(9) + TA)
     IF INTAKE$ = "Y" AND SCS > CDT THEN COLWT = (HT(16) - VCL) * (1 / (TN(1) + TA) - 1 / (TN(9) + TA)) + COLWT
     PB(6) = (353.6 * GC * (COLWT - ((HH + (HT(19) - HT(18))) / (TEF + TA)) + ((HT(19) - HT(18)) / (TN(19) + TA))))
     SN = 1
      IF VF(15) < 0 THEN SN = 0 - 1
     IF GLASSDR$ = "Y" AND SCS > CDT THEN ELA(4) = ELA4GD: ELA(2) = ELA2GD: ELA(3) = ELA(2)
     IF GLASSDR$ = "Y" AND SCS <= CDT THEN ELA(2) = .162: ELA(3) = ELA(2): ELA(4) = .3
     PB(7) = 0 - SN * (473.8 * ((ABS(VF(15)) / ELA(4)) ^ 2) / (TN(15) + TA))
     PB(8) = 0 - SN * (473.8 * ((ABS(VF(18)) / ELA(5)) ^ 2) / (TN(18) + TA))
     IF INTAKE$ = "N" THEN PB3 = 0 ELSE PB3 = -PB(3)
     PB(9) = PB(6) + PB(7) + PB(8)
      REM
      REM :--------CLOSING LOOPS #1 & #2  THROUGH THE DILUTION DEVICE--------
      REM
     SN = 1: II = 2
      IF VF(11) < 0 THEN SN = 0 - 1: II = 3: GOTO 6360
6360 PB(10) = 0 - SN * (473.8 * ((ABS(VF(11)) / ELA(II)) ^ 2) / (TN(11) + TA))
        'LPRINT "LEAVING pressure.par"
END SUB

STATIC SUB print.all ()
'==========================================================================
'
'                       FINAL SYSTEM PRINTOUTS (3750)
'
'==========================================================================
     'LPRINT "ENTERING print.all"
     CALL Print.constants
     CALL print2 ' (13000)
     CALL print.network ' (14000)
     CALL summary.print ' (17000)
     'LPRINT "LEAVING print.all"
END SUB

       STATIC SUB Print.constants ()
REM========================================================================
REM
REM  :  PRINTOUT OF PHYSICAL CONSTANTS OF ALL SYSTEMS (15000)
REM
REM========================================================================
       REM
      'LPRINT "ENTERING print.constants"
      WIDTH #2, 255
      PRINT #2, "PHYSICAL CHARACTERISTICS OF THE SYSTEM"
      PRINT #2, "------------------------------------------": PRINT #2,
       CALL Network.points '(16000)
      PRINT #2, TAB(23);
       FOR X% = 1 TO 19
      PRINT #2, USING "       ##"; X%;
      NEXT
      PRINT #2, "": PRINT #2,
      PRINT #2, "DISTANCE->DATUM (M)";
      PRINT #2, TAB(23);
      FOR X% = 1 TO 19
        PRINT #2, USING "    ##.##"; ABS(HT(X%));
      NEXT X%
      PRINT #2, ""
      PRINT #2, "AREA OF OPENING (m2)";
      PRINT #2, TAB(23);
      FOR X% = 1 TO 19
        PRINT #2, USING "    #.###"; AR(X%);
      NEXT X%
      PRINT #2, ""
      PRINT #2, "K FACTOR NORMAL";
      PRINT #2, TAB(23);
      FOR X% = 1 TO 19
        PRINT #2, USING "      #.#"; KE(X%);
      NEXT X%
      PRINT #2, ""
        'LPRINT "LEAVING print.constants"
END SUB

STATIC SUB print.network ()
'==========================================================================
'
'                FLOW NETWORK PARAMETER OUTPUT (14000)
'
'==========================================================================
       REM
      'LPRINT "ENTERING print.network"
      PRINT #2, : PRINT #2, "THE MASSFLOW SYSTEM PARAMETERS"
      PRINT #2, "-------------------------------"
       CALL Network.points: PRINT #2, : PRINT #2, TAB(23);
       FOR X% = 1 TO 19
      PRINT #2, USING "       ##"; X%;
       NEXT
      PRINT #2, "": PRINT #2,
      PRINT #2,
      PRINT #2, "TEMPERATURE (DEG C)";
      PRINT #2, TAB(23);
       FOR X% = 1 TO 19
      PRINT #2, USING "  ####.# "; TN(X%);
       NEXT X%
      PRINT #2, ""
      PRINT #2, "DENSITY (KG/M3)    ";
      PRINT #2, TAB(23);
       FOR X% = 1 TO 19
      PRINT #2, USING "    ##.##"; RO(X%);
       NEXT X%
      PRINT #2, ""
      PRINT #2, : PRINT #2, "MASS FLOW (KG/S)      ";
      PRINT #2, TAB(23);
       FOR X% = 1 TO 19
      PRINT #2, USING "    #.###"; MF(X%);
       NEXT X%
      PRINT #2, ""
      PRINT #2, "VOLUME FLOW (M3/S) ";
      PRINT #2, TAB(23);
       FOR X% = 1 TO 19
      PRINT #2, USING "    #.###"; VF(X%);
       NEXT X%
      PRINT #2,
      PRINT #2, "FLOW VELOCITY (M/S)";
      PRINT #2, TAB(23);
       FOR X% = 1 TO 19
      PRINT #2, USING "  ###.## "; VL(X%);
       NEXT X%
      PRINT #2, ""
      PRINT #2, : PRINT #2,
      PRINT #2, "PRESSURE PARAMETERS OF THE FLOW SYSTEMS"
      PRINT #2, "---------------------------------------"
      PRINT #2, "         NET BUOYANCY      WIND EFFECT     ENVELOPE LOSS    FRICTION LOSS    NET DRIVING     FIBX BUOYANCY      INLET DROP      OUTLET DROP      NET FIREBOX      DILUTION PORT"
       FOR X% = 1 TO 10
      PRINT #2, USING "          ###.###"; PB(X%);
       NEXT X%
      PRINT #2, ""
      REM:CLS
        'LPRINT "LEAVING print.network"
END SUB

STATIC SUB print1 ()
'==========================================================================
'             PRINT1 (13230)
'==========================================================================
     'LPRINT "ENTERING print1"
     PRINT #2, "FLUE GAS TEMP (C)";
      PRINT #2, TAB(22);
       FOR X% = 1 TO NE%
      PRINT #2, USING "   ###.#"; TI(1, X%);
       NEXT X%
      PRINT #2, ""
      PRINT #2, "INNER LINER    (C)";
      PRINT #2, TAB(22);
       FOR X% = 1 TO NE%
      PRINT #2, USING "   ###.#"; TI(2, X%);
       NEXT X%
      PRINT #2, ""
      IF IND10 = 1 THEN GOTO 13542
      PRINT #2, "INSUL OR STRUCT (C)";
      PRINT #2, TAB(22);
       FOR X% = 1 TO NE%
      PRINT #2, USING "   ###.#"; TI(3, X%);
       NEXT X%
      PRINT #2, ""
      PRINT #2, "OUTER STRUCTURE(C)";
      PRINT #2, TAB(22);
       FOR X% = 1 TO NE%
      PRINT #2, USING "   ###.#"; TI(4, X%);
       NEXT X%
      PRINT #2, ""
      PRINT #2, "SURROUNDING (DEG C)";
      PRINT #2, TAB(22);
       FOR X% = 1 TO NE%
      PRINT #2, USING "   ###.#"; TI(5, X%);
       NEXT X%
      PRINT #2, ""
13542  REM
        'LPRINT "LEAVING print1"
END SUB

STATIC SUB print2 ()
'==========================================================================
'
'        O U T P U T   R O U T I N E S    B E G I N (13000)
'       ROUTINE TO PRINT OUT TEMPERATURES OF THE FLUE ELEMENTS
'
'==========================================================================
       REM
      'LPRINT "ENTERING print2"
      D$ = CHR$(4): REM  : CTRLD VALUE
      PRINT #2, : PRINT #2, : PRINT #2, USING "TIME = ######.# SECONDS"; SCS
      PRINT #2, "===============================": PRINT #2,
      PRINT #2, : PRINT #2, "TEMPERATURES OF THE FLUE GAS, LINER, AND STRUCTURE": PRINT #2, "--------------------------------------------------------": PRINT #2,
      PRINT #2, TAB(23);
       FOR X% = 1 TO 9
       IF X% > NE% THEN GOTO 13210
      PRINT #2, "    F"; X%;
       NEXT
       FOR X% = 10 TO NE%
      PRINT #2, "   F"; X%;
       NEXT
13210 PRINT #2, ""
      PRINT #2,
      CALL print1
'
      'LPRINT "LEAVING print2"
END SUB

STATIC SUB qoutrad1 ()
       
        QOUTRAD = TSTEP * ARWALL(SURFACE%) * EMISS(SURFACE%) * .85 * SBCONST * (((TWALL(SURFACE%, SECTION%) + 273.15) ^ 4) - (TWALL(SURFACE%, SECTION% + 2) + 273.15) ^ 4)

END SUB

STATIC SUB room.surface ()
'==========================================================================
'
'                  CALCULATE Q CONDUCTION FOR ROOM SURFACES (31500)
'
'==========================================================================
'
      'LPRINT "ENTERING room.surface"
      IF GLASSDR$ = "N" THEN QWRISE(5, 1) = 0: QCONDOUT(5) = QIN: GOTO 31540
      IF SECTION% > 1 THEN QWRISE(SURFACE%, SECTION%) = 0: GOTO 31540
      QOUT = TSTEP * EMISS(5) * ARWALL(5) * SBCONST * (((TWALL(5, 1) + 273.15) ^ 4) - (TWALL(5, 11) + 273.15) ^ 4)
      QCONV(5) = TSTEP * HCONVI * ARWALL(5) * (TWALL(5, 1) - ((2 * TINTAKE + TN(6)) / 3)): QCONVL = QCONV(5)
      QCONVOUT(5) = TSTEP * HCONV * ARWALL(5) * (TWALL(5, 1) - TWALL(5, 11)): QCONVEXT = QCONVOUT(5)
      QTRAN = (QWTO5 + QFTO5 + QSTO5)
      QWRISE(5, 1) = (QIN - QTRAN) - QOUT - QCONVL - QCONVEXT
      QCONDOUT(5) = QOUT + QTRAN
31540 REM
        'LPRINT "LEAVING room.surface"
END SUB

STATIC SUB summary.print ()
'==========================================================================
'
'                          SUMMARY TABLE OUTPUT (17000)
'
'==========================================================================
       REM
       'LPRINT "ENTERING summary.print"
       FOR X% = 1 TO 19
      FM(X%) = (INT(1000 * MF(X%) + .5)) / 1000
      TN(X%) = (INT(10 * TN(X%) + .5)) / 10
      VQ(X%) = (INT(10 * VF(X%) * 1000)) / 10
      NEXT X%
      PRINT #2, CHR$(18)
      PRINT #2, : PRINT #2,
      PRINT #2, "S U M M A R Y   T A B L E"
      PRINT #2, "-------------------------"
      PRINT #2,
      PRINT #2, USING "OUTDOOR TEMPERATURE     =    ### C"; T1
      PRINT #2, USING "INDOOR  TEMPERATURE     =    ### C"; T9
      PRINT #2,
      PRINT #2, : PRINT #2,
      PRINT #2, "WIND SPEED & PRESSURE         SPEED     PRESSURE COEFFICIENTS"
      PRINT #2, "COEFFICIENTS:                 (M/S)      CHIM TOP    INSIDE HOUSE"
      PRINT #2, "---------------------          -----     --------    ------------"
      PRINT #2, USING "HORIZONTAL COMPONENT           ##        #.##        #.##"; VH; PHC; CPWENV(LEAKDIST)
      PRINT #2, USING "VERT. COMPONENT (+VE UP)       ##        #.# "; VV; PVC
      PRINT #2, : PRINT #2,
      PRINT #2, "FLOW RATES:                    L/S      KG/S"
      PRINT #2, "-----------                    ---      ----"
      REM E1 =  INT(((MF(16)/(353.6/TA)) - ((286 * FW * 3.413) / 3.6E+09))/ (2.625* FW * 3.413 / 3.6E+09))
      REM E2 =  INT(((MF(6)/(353.6/TA)) - ((286 * FW * 3.413) / 3.6E+09)) / (2.625* FW * 3.413 / 3.6E+09))
      REM IF E1>1000 THEN E1=0 : E2=0
      PRINT #2,
      PRINT #2, USING "FIREBOX OUTLET FLOW           ##.#      #.###"; VQ(18); FM(18)
      PRINT #2, USING "DILUTION AIR FLOW            ###.#      #.###"; VQ(10); FM(10)
      PRINT #2, USING "CHIMNEY INLET FLOW            ##.#      #.###"; VQ(5); FM(5)
      PRINT #2,
      PRINT #2, USING "EXHAUST FAN FLOW              ##.#      #.#"; QF; FANM
      PRINT #2, USING "FLOW FROM COMPETING CHIMNEYS  ##.#      #.#"; FP; FIRM
      PRINT #2, USING "NET ADDITIONAL ENVELOPE FLOW  ##.#    ###.# (AT OUTDOOR TEMPERATURE)"; VQ(8); FM(8)
      PRINT #2, USING "INDUCED PRESSURE DROP ACROSS THE ENVELOPE = ##.# Pa"; PB(3)
      PRINT #2, : PRINT #2, : PRINT #2, "TEMPERATURES:"
      PRINT #2, "---------------": PRINT #2,
      PRINT #2, USING "AIR TEMPERATURE ABOVE FLAME= ####.  C"; TN(16)
      PRINT #2, USING "FIREBOX EXIT  TEMPERATURE  =  ###.# C"; TN(17)
      PRINT #2, USING "CHIM GAS T. AFTER DILUTION =  ###.# C"; TN(6)
      TT = 0: TQ = 0
       FOR Y% = 1 TO NE%
      TT = TT + TI(1, Y%)
      TQ = TQ + TI(2, Y%)
       NEXT Y%
      TT = TT / NE%: TQ = TQ / NE%
      PRINT #2, USING "MEAN FLUE GAS TEMPERATURE =   ###.# C"; TT
      PRINT #2, USING "MEAN FLUE LINER TEMPERATURE=  ###.# C"; TQ
      PRINT #2, : PRINT #2, : PRINT #2,
      PRINT #2, "THERMAL PROPERTIES OF FIREBOX & CHIMNEY"
      PRINT #2, "---------------------------------------": PRINT #2,
      PRINT #2,
      PRINT #2, "AT THE BASE OF THE CHIMNEY:                        FLUE GAS       LINER         SLEEVE      STRUCTURE"
      PRINT #2, "--------------------------                         --------       -----         ------      ---------"
      PRINT #2, "HEAT TRANSFER COEFF. 'U' (W/(m2.C))        "; : PRINT #2, USING "   #######.###"; UF; U(2, NFPSEGS% + 1); U(3, NFPSEGS% + 1); U(4, NFPSEGS% + 1)
      PRINT #2, "ELEMENTAL SURFACE AREA 'A' (m2)            "; : PRINT #2, USING "    ######.###"; A(1, NFPSEGS% + 1); A(2, NFPSEGS% + 1); A(3, NFPSEGS% + 1); A(4, NFPSEGS% + 1)
      PRINT #2, "ELEMENTAL MASS 'M' (KG)                    "; : PRINT #2, USING "   #######.###"; M(1, NFPSEGS% + 1); M(2, NFPSEGS% + 1); M(3, NFPSEGS% + 1); M(4, NFPSEGS% + 1)
      PRINT #2, "HEAT CAPACITY OF MATERIALS 'CP'  (W.S/KG.C)"; : PRINT #2, USING "   #######.#  "; HC(1, NFPSEGS% + 1); HC(2, NFPSEGS% + 1); HC(3, NFPSEGS% + 1); HC(4, NFPSEGS% + 1)
      PRINT #2, "HEAT TRANSFER TIME CONSTANTS-OUT (S)       ";
      FOR J% = 1 TO 4
        IF J% = 1 THEN TW(J%) = (M(J%, NFPSEGS% + 1) * HC(J%, NFPSEGS% + 1)) / (UF * A(J%, NFPSEGS% + 1)): GOTO 17740
        TW(J%) = (M(J%, NFPSEGS% + 1) * HC(J%, NFPSEGS% + 1)) / (U(J%, NFPSEGS% + 1) * A(J%, NFPSEGS% + 1))
17740   PRINT #2, USING "   #######.#  "; TW(J%);
      NEXT J%
      PRINT #2,
      PRINT #2, "HEAT TRANSFER TIME CONSTANTS-IN  (S)       ";
      PRINT #2, "              ";
      FOR J% = 2 TO 4
        TW(J%) = (M(J%, NFPSEGS% + 1) * HC(J%, NFPSEGS% + 1)) / (U(J% - 1, NFPSEGS% + 1) * A(J% - 1, NFPSEGS% + 1))
        PRINT #2, USING "   #######.#  "; TW(J%);
      NEXT J%
      PRINT #2, : PRINT #2, : PRINT #2,
      PRINT #2, "ENVELOPE CHARACTERISTICS:       WITHOUT     WITH"
      PRINT #2, "------------------------        AIR INTAKE  AIR INTAKE (IF ANY)"
      PRINT #2, "                                ----------  ----------"
      PRINT #2, USING "FLOW COEFFICIENT (M3/(S.PA^N) = #.####      #.####"; C; CC
      PRINT #2, USING "FLOW EXPONENT    (--)         = #.###       #.###"; N; N
      PRINT #2, USING "LOCATION OF VCL BELOW CHIM TOP= #.##        #.##(m)"; ABS(LNPP); ABS(VCL)
      PRINT #2, : PRINT #2, : PRINT #2,
      PRINT #2, "FRESH AIR INTAKE TO THE FIREBOX"
      PRINT #2, "-------------------------------": PRINT #2,
      IF INTAKE$ = "N" THEN PRINT #2, "----- NONE -----": GOTO 17912
      PRINT #2, USING "THE INTAKE ELA (m2)  =  #.#####"; ELA(4)
17912 PRINT #2, : PRINT #2, "ELA OF THE FIREDOOR"
      PRINT #2, "------------------": PRINT #2,
      IF GLASSDR$ = "N" THEN PRINT #2, "----- NONE -----": GOTO 17999
      IF INTAKE$ = "Y" THEN PRINT #2, USING "THE FIREDOOR ELA (m2) = #.####"; ELA(2): GOTO 17999
      PRINT #2, USING "THE FIREBOX 'DILUTION OPENING'  ELA  = #.#### (m2)"; ELA(2)
      PRINT #2, USING "THE FIREBOX 'COMBUSTION INTAKE' ELA  = #.#### (m2)"; ELA(4)
      PRINT #2, USING "IF THERE IS AN INTAKE GRILL THEN THE DOOR ELA IS THE DILUTION OPENING = #.#### (m2)"; ELA(2)
      PRINT #2, USING "IF THERE IS NO INTAKE GRILL BELOW THE DOORS THEN THE TOTAL DOOR ELA   = #.#### (m2)"; (ELA(2) + ELA(4))
17999  REM
        'LPRINT "LEAVING summary.print"
END SUB

STATIC SUB temp.update ()
'==========================================================================
'
'         T E M P E R A T U R E    U P D A T E  (12020)
'                ---PARAMETERIZED ALGORITHMS---
'
'==========================================================================
       REM
       'LPRINT "ENTERING temp.update"
       IF INDT = 1 AND SEC > .9 * ABS(ITW) THEN SEC = .9 * ABS(ITW)
       IF INDT = 2 AND SEC > .3 * ABS(ITW) THEN SEC = .3 * ABS(ITW)
       IF D1TM = 0 THEN GOTO 12130
      TR = (D2TM / OTW) * (ITW / D1TM)
      DTM = D1TM * (1 - TR) * (SEC / ITW)
       GOTO 12180
12130  IF D2TM = 0 THEN DTM = 0: GOTO 12180
       IF INDT = 1 AND SEC > .9 * ABS(OTW) THEN SEC = .9 * ABS(OTW)
       IF INDT = 2 AND SEC > .3 * ABS(OTW) THEN SEC = .3 * ABS(OTW)
      TR = (D1TM / ITW) * (OTW / D2TM)
      DTM = D2TM * (TR - 1) * (SEC / OTW)
12180  REM
        'LPRINT "LEAVING temp.update"
END SUB

STATIC SUB values.pr2 ()
'==========================================================================
'
'                 ASSIGN VALUES FOR .PR2 FILE (19300)
'
'==========================================================================
      'LPRINT "ENTERING values.pr2"
      OOW(1) = SCS
      OOW(2) = FW / 1000!
      OOW(3) = TWALL(5, 1)
      OOW(4) = TWALL(2, 1)
      OOW(5) = TWALL(1, 1)
      OOW(6) = TWALL(4, 1)
      OOW(7) = TWALL(2, 4)
      OOW(8) = TWALL(1, 4)
      OOW(9) = TWALL(2, 10)
      OOW(10) = TWALL(1, 10)
      OOW(11) = TOTRAD(5) / 3600!
      OOW(12) = TRADFL
      OOW(13) = SOURCEQ / 3600!
      OOW(14) = TQFLUE / 3600!
      OOW(15) = TOTFLRAD / 3600!
      OOW(16) = TWDRAD / 3600!
      OOW(17) = 100 - (100 * (TDMASSL + 1E-29) / (TMASSL + 1E-29))
      OOW(18) = (100 - (100 * (TDBURNED + 1E-29) / (TMASCOMB + 1E-29)))
      IF OOW(17) > 1000 THEN OOW(17) = 0
      IF OOW(18) > 1000 THEN OOW(18) = 0
        'LPRINT "LEAVING values.pr2"
END SUB

